"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class StepsOverridesTypedDict(TypedDict):
    providers: Dict[str, Dict[str, Any]]
    r"""Passing the provider id and the provider specific configurations"""


class StepsOverrides(BaseModel):
    providers: Dict[str, Dict[str, Any]]
    r"""Passing the provider id and the provider specific configurations"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .constraintvalidation import ConstraintValidation
from novu_py import utils
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET
import pydantic
from typing import Any, Dict, List, Optional, Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


MessageValidationErrorDto5TypedDict = TypeAliasType(
    "MessageValidationErrorDto5TypedDict", Union[str, float, bool, Dict[str, Any]]
)


MessageValidationErrorDto5 = TypeAliasType(
    "MessageValidationErrorDto5", Union[str, float, bool, Dict[str, Any]]
)


class MessageValidationErrorDto4TypedDict(TypedDict):
    pass


class MessageValidationErrorDto4(BaseModel):
    pass


ValidationErrorDtoMessageTypedDict = TypeAliasType(
    "ValidationErrorDtoMessageTypedDict",
    Union[
        MessageValidationErrorDto4TypedDict,
        str,
        float,
        bool,
        List[Nullable[MessageValidationErrorDto5TypedDict]],
    ],
)
r"""Value that failed validation"""


ValidationErrorDtoMessage = TypeAliasType(
    "ValidationErrorDtoMessage",
    Union[
        MessageValidationErrorDto4,
        str,
        float,
        bool,
        List[Nullable[MessageValidationErrorDto5]],
    ],
)
r"""Value that failed validation"""


class ValidationErrorDtoData(BaseModel):
    status_code: Annotated[float, pydantic.Field(alias="statusCode")]
    r"""HTTP status code of the error response."""

    timestamp: str
    r"""Timestamp of when the error occurred."""

    path: str
    r"""The path where the error occurred."""

    errors: Dict[str, ConstraintValidation]
    r"""A record of validation errors keyed by field name"""

    message: OptionalNullable[ValidationErrorDtoMessage] = UNSET
    r"""Value that failed validation"""

    ctx: Optional[Dict[str, Any]] = None
    r"""Optional context object for additional error details."""

    error_id: Annotated[Optional[str], pydantic.Field(alias="errorId")] = None
    r"""Optional unique identifier for the error, useful for tracking using Sentry and
    New Relic, only available for 500.
    """


class ValidationErrorDto(Exception):
    data: ValidationErrorDtoData

    def __init__(self, data: ValidationErrorDtoData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, ValidationErrorDtoData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .stepsoverrides import StepsOverrides, StepsOverridesTypedDict
from .subscriberpayloaddto import SubscriberPayloadDto, SubscriberPayloadDtoTypedDict
from .tenantpayloaddto import TenantPayloadDto, TenantPayloadDtoTypedDict
from .topicpayloaddto import TopicPayloadDto, TopicPayloadDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class OverridesTypedDict(TypedDict):
    r"""This could be used to override provider specific configurations"""

    steps: NotRequired[Dict[str, StepsOverridesTypedDict]]
    r"""This could be used to override provider specific configurations"""
    providers: NotRequired[Dict[str, Dict[str, Any]]]
    r"""Overrides the provider configuration for the entire workflow and all steps"""
    email: NotRequired[Dict[str, Any]]
    r"""Override the email provider specific configurations for the entire workflow"""
    push: NotRequired[Dict[str, Any]]
    r"""Override the push provider specific configurations for the entire workflow"""
    sms: NotRequired[Dict[str, Any]]
    r"""Override the sms provider specific configurations for the entire workflow"""
    chat: NotRequired[Dict[str, Any]]
    r"""Override the chat provider specific configurations for the entire workflow"""
    layout_identifier: NotRequired[str]
    r"""Override the layout identifier for the entire workflow"""


class Overrides(BaseModel):
    r"""This could be used to override provider specific configurations"""

    steps: Optional[Dict[str, StepsOverrides]] = None
    r"""This could be used to override provider specific configurations"""

    providers: Optional[Dict[str, Dict[str, Any]]] = None
    r"""Overrides the provider configuration for the entire workflow and all steps"""

    email: Annotated[
        Optional[Dict[str, Any]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Override the email provider specific configurations for the entire workflow"""

    push: Annotated[
        Optional[Dict[str, Any]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Override the push provider specific configurations for the entire workflow"""

    sms: Annotated[
        Optional[Dict[str, Any]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Override the sms provider specific configurations for the entire workflow"""

    chat: Annotated[
        Optional[Dict[str, Any]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Override the chat provider specific configurations for the entire workflow"""

    layout_identifier: Annotated[
        Optional[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible.",
            alias="layoutIdentifier",
        ),
    ] = None
    r"""Override the layout identifier for the entire workflow"""


OneTypedDict = TypeAliasType(
    "OneTypedDict", Union[TopicPayloadDtoTypedDict, SubscriberPayloadDtoTypedDict, str]
)


One = TypeAliasType("One", Union[TopicPayloadDto, SubscriberPayloadDto, str])


ToTypedDict = TypeAliasType(
    "ToTypedDict",
    Union[
        TopicPayloadDtoTypedDict, SubscriberPayloadDtoTypedDict, List[OneTypedDict], str
    ],
)
r"""The recipients list of people who will receive the notification."""


To = TypeAliasType("To", Union[TopicPayloadDto, SubscriberPayloadDto, List[One], str])
r"""The recipients list of people who will receive the notification."""


ActorTypedDict = TypeAliasType(
    "ActorTypedDict", Union[SubscriberPayloadDtoTypedDict, str]
)
r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.

If a new actor object is provided, we will create a new subscriber in our system
"""


Actor = TypeAliasType("Actor", Union[SubscriberPayloadDto, str])
r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.

If a new actor object is provided, we will create a new subscriber in our system
"""


TenantTypedDict = TypeAliasType(
    "TenantTypedDict", Union[TenantPayloadDtoTypedDict, str]
)
r"""It is used to specify a tenant context during trigger event.
Existing tenants will be updated with the provided details.
"""


Tenant = TypeAliasType("Tenant", Union[TenantPayloadDto, str])
r"""It is used to specify a tenant context during trigger event.
Existing tenants will be updated with the provided details.
"""


class TriggerEventRequestDtoTypedDict(TypedDict):
    workflow_id: str
    r"""The trigger identifier of the workflow you wish to send. This identifier can be found on the workflow page."""
    to: ToTypedDict
    r"""The recipients list of people who will receive the notification."""
    payload: NotRequired[Dict[str, Any]]
    r"""The payload object is used to pass additional custom information that could be
    used to render the workflow, or perform routing rules based on it.
    This data will also be available when fetching the notifications feed from the API to display certain parts of the UI.
    """
    overrides: NotRequired[OverridesTypedDict]
    r"""This could be used to override provider specific configurations"""
    transaction_id: NotRequired[str]
    r"""A unique identifier for this transaction, we will generate a UUID if not provided."""
    actor: NotRequired[ActorTypedDict]
    r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.

    If a new actor object is provided, we will create a new subscriber in our system
    """
    tenant: NotRequired[TenantTypedDict]
    r"""It is used to specify a tenant context during trigger event.
    Existing tenants will be updated with the provided details.
    """


class TriggerEventRequestDto(BaseModel):
    workflow_id: Annotated[str, pydantic.Field(alias="name")]
    r"""The trigger identifier of the workflow you wish to send. This identifier can be found on the workflow page."""

    to: To
    r"""The recipients list of people who will receive the notification."""

    payload: Optional[Dict[str, Any]] = None
    r"""The payload object is used to pass additional custom information that could be
    used to render the workflow, or perform routing rules based on it.
    This data will also be available when fetching the notifications feed from the API to display certain parts of the UI.
    """

    overrides: Optional[Overrides] = None
    r"""This could be used to override provider specific configurations"""

    transaction_id: Annotated[Optional[str], pydantic.Field(alias="transactionId")] = (
        None
    )
    r"""A unique identifier for this transaction, we will generate a UUID if not provided."""

    actor: Optional[Actor] = None
    r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.

    If a new actor object is provided, we will create a new subscriber in our system
    """

    tenant: Optional[Tenant] = None
    r"""It is used to specify a tenant context during trigger event.
    Existing tenants will be updated with the provided details.
    """



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .activitynotificationjobresponsedto import (
    ActivityNotificationJobResponseDto,
    ActivityNotificationJobResponseDtoTypedDict,
)
from .activitynotificationsubscriberresponsedto import (
    ActivityNotificationSubscriberResponseDto,
    ActivityNotificationSubscriberResponseDtoTypedDict,
)
from .activitynotificationtemplateresponsedto import (
    ActivityNotificationTemplateResponseDto,
    ActivityNotificationTemplateResponseDtoTypedDict,
)
from .activitytopicdto import ActivityTopicDto, ActivityTopicDtoTypedDict
from .steptypeenum import StepTypeEnum
from novu_py.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ActivityNotificationResponseDtoPayloadTypedDict(TypedDict):
    r"""Payload of the notification"""


class ActivityNotificationResponseDtoPayload(BaseModel):
    r"""Payload of the notification"""


class ControlsTypedDict(TypedDict):
    r"""Controls associated with the notification"""


class Controls(BaseModel):
    r"""Controls associated with the notification"""


class ActivityNotificationResponseDtoToTypedDict(TypedDict):
    r"""To field for subscriber definition"""


class ActivityNotificationResponseDtoTo(BaseModel):
    r"""To field for subscriber definition"""


class ActivityNotificationResponseDtoTypedDict(TypedDict):
    environment_id: str
    r"""Environment ID of the notification"""
    organization_id: str
    r"""Organization ID of the notification"""
    subscriber_id: str
    r"""Subscriber ID of the notification"""
    transaction_id: str
    r"""Transaction ID of the notification"""
    id: NotRequired[str]
    r"""Unique identifier of the notification"""
    template_id: NotRequired[str]
    r"""Template ID of the notification"""
    digested_notification_id: NotRequired[str]
    r"""Digested Notification ID"""
    created_at: NotRequired[str]
    r"""Creation time of the notification"""
    updated_at: NotRequired[str]
    r"""Last updated time of the notification"""
    channels: NotRequired[List[StepTypeEnum]]
    subscriber: NotRequired[ActivityNotificationSubscriberResponseDtoTypedDict]
    r"""Subscriber of the notification"""
    template: NotRequired[ActivityNotificationTemplateResponseDtoTypedDict]
    r"""Template of the notification"""
    jobs: NotRequired[List[ActivityNotificationJobResponseDtoTypedDict]]
    r"""Jobs of the notification"""
    payload: NotRequired[ActivityNotificationResponseDtoPayloadTypedDict]
    r"""Payload of the notification"""
    tags: NotRequired[List[str]]
    r"""Tags associated with the notification"""
    controls: NotRequired[ControlsTypedDict]
    r"""Controls associated with the notification"""
    to: NotRequired[ActivityNotificationResponseDtoToTypedDict]
    r"""To field for subscriber definition"""
    topics: NotRequired[List[ActivityTopicDtoTypedDict]]
    r"""Topics of the notification"""


class ActivityNotificationResponseDto(BaseModel):
    environment_id: Annotated[str, pydantic.Field(alias="_environmentId")]
    r"""Environment ID of the notification"""

    organization_id: Annotated[str, pydantic.Field(alias="_organizationId")]
    r"""Organization ID of the notification"""

    subscriber_id: Annotated[str, pydantic.Field(alias="_subscriberId")]
    r"""Subscriber ID of the notification"""

    transaction_id: Annotated[str, pydantic.Field(alias="transactionId")]
    r"""Transaction ID of the notification"""

    id: Annotated[Optional[str], pydantic.Field(alias="_id")] = None
    r"""Unique identifier of the notification"""

    template_id: Annotated[Optional[str], pydantic.Field(alias="_templateId")] = None
    r"""Template ID of the notification"""

    digested_notification_id: Annotated[
        Optional[str], pydantic.Field(alias="_digestedNotificationId")
    ] = None
    r"""Digested Notification ID"""

    created_at: Annotated[Optional[str], pydantic.Field(alias="createdAt")] = None
    r"""Creation time of the notification"""

    updated_at: Annotated[Optional[str], pydantic.Field(alias="updatedAt")] = None
    r"""Last updated time of the notification"""

    channels: Optional[List[StepTypeEnum]] = None

    subscriber: Optional[ActivityNotificationSubscriberResponseDto] = None
    r"""Subscriber of the notification"""

    template: Optional[ActivityNotificationTemplateResponseDto] = None
    r"""Template of the notification"""

    jobs: Optional[List[ActivityNotificationJobResponseDto]] = None
    r"""Jobs of the notification"""

    payload: Optional[ActivityNotificationResponseDtoPayload] = None
    r"""Payload of the notification"""

    tags: Optional[List[str]] = None
    r"""Tags associated with the notification"""

    controls: Optional[Controls] = None
    r"""Controls associated with the notification"""

    to: Optional[ActivityNotificationResponseDtoTo] = None
    r"""To field for subscriber definition"""

    topics: Optional[List[ActivityTopicDto]] = None
    r"""Topics of the notification"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .deletetopicsubscriptionsrequestdto import (
    DeleteTopicSubscriptionsRequestDto,
    DeleteTopicSubscriptionsRequestDtoTypedDict,
)
from .deletetopicsubscriptionsresponsedto import (
    DeleteTopicSubscriptionsResponseDto,
    DeleteTopicSubscriptionsResponseDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TopicsControllerDeleteTopicSubscriptionsRequestTypedDict(TypedDict):
    topic_key: str
    r"""The key identifier of the topic"""
    delete_topic_subscriptions_request_dto: DeleteTopicSubscriptionsRequestDtoTypedDict
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class TopicsControllerDeleteTopicSubscriptionsRequest(BaseModel):
    topic_key: Annotated[
        str,
        pydantic.Field(alias="topicKey"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The key identifier of the topic"""

    delete_topic_subscriptions_request_dto: Annotated[
        DeleteTopicSubscriptionsRequestDto,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class TopicsControllerDeleteTopicSubscriptionsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: DeleteTopicSubscriptionsResponseDtoTypedDict


class TopicsControllerDeleteTopicSubscriptionsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: DeleteTopicSubscriptionsResponseDto



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .activitiesresponsedto import (
        ActivitiesResponseDto,
        ActivitiesResponseDtoTypedDict,
    )
    from .activitynotificationexecutiondetailresponsedto import (
        ActivityNotificationExecutionDetailResponseDto,
        ActivityNotificationExecutionDetailResponseDtoTypedDict,
    )
    from .activitynotificationjobresponsedto import (
        ActivityNotificationJobResponseDto,
        ActivityNotificationJobResponseDtoPayload,
        ActivityNotificationJobResponseDtoPayloadTypedDict,
        ActivityNotificationJobResponseDtoType,
        ActivityNotificationJobResponseDtoTypedDict,
    )
    from .activitynotificationresponsedto import (
        ActivityNotificationResponseDto,
        ActivityNotificationResponseDtoPayload,
        ActivityNotificationResponseDtoPayloadTypedDict,
        ActivityNotificationResponseDtoTo,
        ActivityNotificationResponseDtoToTypedDict,
        ActivityNotificationResponseDtoTypedDict,
        Controls,
        ControlsTypedDict,
    )
    from .activitynotificationstepresponsedto import (
        ActivityNotificationStepResponseDto,
        ActivityNotificationStepResponseDtoMetadata,
        ActivityNotificationStepResponseDtoMetadataTypedDict,
        ActivityNotificationStepResponseDtoReplyCallback,
        ActivityNotificationStepResponseDtoReplyCallbackTypedDict,
        ActivityNotificationStepResponseDtoTypedDict,
        ControlVariables,
        ControlVariablesTypedDict,
        Issues,
        IssuesTypedDict,
    )
    from .activitynotificationsubscriberresponsedto import (
        ActivityNotificationSubscriberResponseDto,
        ActivityNotificationSubscriberResponseDtoTypedDict,
    )
    from .activitynotificationtemplateresponsedto import (
        ActivityNotificationTemplateResponseDto,
        ActivityNotificationTemplateResponseDtoTypedDict,
    )
    from .activitytopicdto import ActivityTopicDto, ActivityTopicDtoTypedDict
    from .actorfeeditemdto import ActorFeedItemDto, ActorFeedItemDtoTypedDict
    from .actortypeenum import ActorTypeEnum
    from .apierror import APIError
    from .builderfieldtypeenum import BuilderFieldTypeEnum
    from .bulkcreatesubscriberresponsedto import (
        BulkCreateSubscriberResponseDto,
        BulkCreateSubscriberResponseDtoTypedDict,
    )
    from .bulksubscribercreatedto import (
        BulkSubscriberCreateDto,
        BulkSubscriberCreateDtoTypedDict,
    )
    from .bulktriggereventdto import BulkTriggerEventDto, BulkTriggerEventDtoTypedDict
    from .buttontypeenum import ButtonTypeEnum
    from .channelcredentials import ChannelCredentials, ChannelCredentialsTypedDict
    from .channelcredentialsdto import (
        ChannelCredentialsDto,
        ChannelCredentialsDtoTypedDict,
    )
    from .channelctatypeenum import ChannelCTATypeEnum
    from .channelsettingsdto import ChannelSettingsDto, ChannelSettingsDtoTypedDict
    from .channeltypeenum import ChannelTypeEnum
    from .chatorpushproviderenum import ChatOrPushProviderEnum
    from .constraintvalidation import (
        ConstraintValidation,
        ConstraintValidationTypedDict,
        Five,
        FiveTypedDict,
        Four,
        FourTypedDict,
        Value,
        ValueTypedDict,
    )
    from .createdsubscriberdto import (
        CreatedSubscriberDto,
        CreatedSubscriberDtoTypedDict,
    )
    from .createintegrationrequestdto import (
        CreateIntegrationRequestDto,
        CreateIntegrationRequestDtoChannel,
        CreateIntegrationRequestDtoTypedDict,
    )
    from .createsubscriberrequestdto import (
        CreateSubscriberRequestDto,
        CreateSubscriberRequestDtoTypedDict,
    )
    from .createtopicsubscriptionsrequestdto import (
        CreateTopicSubscriptionsRequestDto,
        CreateTopicSubscriptionsRequestDtoTypedDict,
    )
    from .createtopicsubscriptionsresponsedto import (
        CreateTopicSubscriptionsResponseDto,
        CreateTopicSubscriptionsResponseDtoTypedDict,
    )
    from .createupdatetopicrequestdto import (
        CreateUpdateTopicRequestDto,
        CreateUpdateTopicRequestDtoTypedDict,
    )
    from .credentialsdto import (
        CredentialsDto,
        CredentialsDtoTypedDict,
        TLSOptions,
        TLSOptionsTypedDict,
    )
    from .delayregularmetadata import (
        DelayRegularMetadata,
        DelayRegularMetadataType,
        DelayRegularMetadataTypedDict,
        DelayRegularMetadataUnit,
    )
    from .delayscheduledmetadata import (
        DelayScheduledMetadata,
        DelayScheduledMetadataType,
        DelayScheduledMetadataTypedDict,
    )
    from .deletemessageresponsedto import (
        DeleteMessageResponseDto,
        DeleteMessageResponseDtoStatus,
        DeleteMessageResponseDtoTypedDict,
    )
    from .deletetopicresponsedto import (
        DeleteTopicResponseDto,
        DeleteTopicResponseDtoTypedDict,
    )
    from .deletetopicsubscriptionsrequestdto import (
        DeleteTopicSubscriptionsRequestDto,
        DeleteTopicSubscriptionsRequestDtoTypedDict,
    )
    from .deletetopicsubscriptionsresponsedto import (
        DeleteTopicSubscriptionsResponseDto,
        DeleteTopicSubscriptionsResponseDtoTypedDict,
    )
    from .digestmetadatadto import (
        DigestMetadataDto,
        DigestMetadataDtoTypedDict,
        DigestMetadataDtoUnit,
    )
    from .digestregularmetadata import (
        BackoffUnit,
        DigestRegularMetadata,
        DigestRegularMetadataTypedDict,
        Type,
        Unit,
    )
    from .digesttimedconfigdto import (
        DigestTimedConfigDto,
        DigestTimedConfigDtoTypedDict,
        DigestTimedConfigDtoWeekDays,
    )
    from .digesttimedmetadata import (
        DigestTimedMetadata,
        DigestTimedMetadataType,
        DigestTimedMetadataTypedDict,
        DigestTimedMetadataUnit,
    )
    from .digesttypeenum import DigestTypeEnum
    from .digestunitenum import DigestUnitEnum
    from .emailblock import EmailBlock, EmailBlockTypedDict
    from .emailblockstyles import EmailBlockStyles, EmailBlockStylesTypedDict
    from .emailblocktypeenum import EmailBlockTypeEnum
    from .errordto import (
        ErrorDto,
        ErrorDtoData,
        Message,
        Message4,
        Message4TypedDict,
        Message5,
    )
    from .eventscontroller_broadcasteventtoallop import (
        EventsControllerBroadcastEventToAllRequest,
        EventsControllerBroadcastEventToAllRequestTypedDict,
        EventsControllerBroadcastEventToAllResponse,
        EventsControllerBroadcastEventToAllResponseTypedDict,
    )
    from .eventscontroller_cancelop import (
        EventsControllerCancelRequest,
        EventsControllerCancelRequestTypedDict,
        EventsControllerCancelResponse,
        EventsControllerCancelResponseTypedDict,
    )
    from .eventscontroller_triggerbulkop import (
        EventsControllerTriggerBulkRequest,
        EventsControllerTriggerBulkRequestTypedDict,
        EventsControllerTriggerBulkResponse,
        EventsControllerTriggerBulkResponseTypedDict,
    )
    from .eventscontroller_triggerop import (
        EventsControllerTriggerRequest,
        EventsControllerTriggerRequestTypedDict,
        EventsControllerTriggerResponse,
        EventsControllerTriggerResponseTypedDict,
    )
    from .executiondetailssourceenum import ExecutionDetailsSourceEnum
    from .executiondetailsstatusenum import ExecutionDetailsStatusEnum
    from .failedoperationdto import FailedOperationDto, FailedOperationDtoTypedDict
    from .feedresponsedto import FeedResponseDto, FeedResponseDtoTypedDict
    from .fieldfilterpartdto import (
        FieldFilterPartDto,
        FieldFilterPartDtoTypedDict,
        On,
        Operator,
    )
    from .getsubscriberpreferencesdto import (
        GetSubscriberPreferencesDto,
        GetSubscriberPreferencesDtoTypedDict,
    )
    from .integrationresponsedto import (
        Channel,
        IntegrationResponseDto,
        IntegrationResponseDtoTypedDict,
    )
    from .integrationscontroller_createintegrationop import (
        IntegrationsControllerCreateIntegrationRequest,
        IntegrationsControllerCreateIntegrationRequestTypedDict,
        IntegrationsControllerCreateIntegrationResponse,
        IntegrationsControllerCreateIntegrationResponseTypedDict,
    )
    from .integrationscontroller_getactiveintegrationsop import (
        IntegrationsControllerGetActiveIntegrationsRequest,
        IntegrationsControllerGetActiveIntegrationsRequestTypedDict,
        IntegrationsControllerGetActiveIntegrationsResponse,
        IntegrationsControllerGetActiveIntegrationsResponseTypedDict,
    )
    from .integrationscontroller_listintegrationsop import (
        IntegrationsControllerListIntegrationsRequest,
        IntegrationsControllerListIntegrationsRequestTypedDict,
        IntegrationsControllerListIntegrationsResponse,
        IntegrationsControllerListIntegrationsResponseTypedDict,
    )
    from .integrationscontroller_removeintegrationop import (
        IntegrationsControllerRemoveIntegrationRequest,
        IntegrationsControllerRemoveIntegrationRequestTypedDict,
        IntegrationsControllerRemoveIntegrationResponse,
        IntegrationsControllerRemoveIntegrationResponseTypedDict,
    )
    from .integrationscontroller_setintegrationasprimaryop import (
        IntegrationsControllerSetIntegrationAsPrimaryRequest,
        IntegrationsControllerSetIntegrationAsPrimaryRequestTypedDict,
        IntegrationsControllerSetIntegrationAsPrimaryResponse,
        IntegrationsControllerSetIntegrationAsPrimaryResponseTypedDict,
    )
    from .integrationscontroller_updateintegrationbyidop import (
        IntegrationsControllerUpdateIntegrationByIDRequest,
        IntegrationsControllerUpdateIntegrationByIDRequestTypedDict,
        IntegrationsControllerUpdateIntegrationByIDResponse,
        IntegrationsControllerUpdateIntegrationByIDResponseTypedDict,
    )
    from .listsubscribersresponsedto import (
        ListSubscribersResponseDto,
        ListSubscribersResponseDtoTypedDict,
    )
    from .listtopicsresponsedto import (
        ListTopicsResponseDto,
        ListTopicsResponseDtoTypedDict,
    )
    from .listtopicsubscriptionsresponsedto import (
        ListTopicSubscriptionsResponseDto,
        ListTopicSubscriptionsResponseDtoTypedDict,
    )
    from .markallmessageasrequestdto import (
        FeedIdentifier,
        FeedIdentifierTypedDict,
        MarkAllMessageAsRequestDto,
        MarkAllMessageAsRequestDtoTypedDict,
        MarkAs,
    )
    from .markmessageactionasseendto import (
        MarkMessageActionAsSeenDto,
        MarkMessageActionAsSeenDtoPayload,
        MarkMessageActionAsSeenDtoPayloadTypedDict,
        MarkMessageActionAsSeenDtoStatus,
        MarkMessageActionAsSeenDtoTypedDict,
    )
    from .messageaction import MessageAction, MessageActionTypedDict
    from .messageactionresult import (
        MessageActionResult,
        MessageActionResultTypedDict,
        Payload,
        PayloadTypedDict,
    )
    from .messageactionstatusenum import MessageActionStatusEnum
    from .messagebutton import MessageButton, MessageButtonTypedDict
    from .messagecta import MessageCTA, MessageCTATypedDict
    from .messagectadata import MessageCTAData, MessageCTADataTypedDict
    from .messagemarkasrequestdto import (
        MessageID,
        MessageIDTypedDict,
        MessageMarkAsRequestDto,
        MessageMarkAsRequestDtoMarkAs,
        MessageMarkAsRequestDtoTypedDict,
    )
    from .messageresponsedto import (
        Content,
        ContentTypedDict,
        MessageResponseDto,
        MessageResponseDtoOverrides,
        MessageResponseDtoOverridesTypedDict,
        MessageResponseDtoPayload,
        MessageResponseDtoPayloadTypedDict,
        MessageResponseDtoTypedDict,
    )
    from .messagescontroller_deletemessageop import (
        MessagesControllerDeleteMessageRequest,
        MessagesControllerDeleteMessageRequestTypedDict,
        MessagesControllerDeleteMessageResponse,
        MessagesControllerDeleteMessageResponseTypedDict,
    )
    from .messagescontroller_deletemessagesbytransactionidop import (
        MessagesControllerDeleteMessagesByTransactionIDRequest,
        MessagesControllerDeleteMessagesByTransactionIDRequestTypedDict,
        MessagesControllerDeleteMessagesByTransactionIDResponse,
        MessagesControllerDeleteMessagesByTransactionIDResponseTypedDict,
        QueryParamChannel,
    )
    from .messagescontroller_getmessagesop import (
        MessagesControllerGetMessagesRequest,
        MessagesControllerGetMessagesRequestTypedDict,
        MessagesControllerGetMessagesResponse,
        MessagesControllerGetMessagesResponseTypedDict,
    )
    from .messagesresponsedto import MessagesResponseDto, MessagesResponseDtoTypedDict
    from .messagestatusenum import MessageStatusEnum
    from .messagetemplate import MessageTemplate, MessageTemplateTypedDict
    from .messagetemplatedto import MessageTemplateDto, MessageTemplateDtoTypedDict
    from .metadto import MetaDto, MetaDtoTypedDict
    from .monthlytypeenum import MonthlyTypeEnum
    from .notificationfeeditemdto import (
        NotificationFeedItemDto,
        NotificationFeedItemDtoStatus,
        NotificationFeedItemDtoTypedDict,
    )
    from .notificationgroup import NotificationGroup, NotificationGroupTypedDict
    from .notificationscontroller_getnotificationop import (
        NotificationsControllerGetNotificationRequest,
        NotificationsControllerGetNotificationRequestTypedDict,
        NotificationsControllerGetNotificationResponse,
        NotificationsControllerGetNotificationResponseTypedDict,
    )
    from .notificationscontroller_listnotificationsop import (
        NotificationsControllerListNotificationsRequest,
        NotificationsControllerListNotificationsRequestTypedDict,
        NotificationsControllerListNotificationsResponse,
        NotificationsControllerListNotificationsResponseTypedDict,
    )
    from .notificationstepdata import (
        NotificationStepData,
        NotificationStepDataMetadata,
        NotificationStepDataMetadataTypedDict,
        NotificationStepDataTypedDict,
    )
    from .notificationstepdto import (
        Metadata,
        MetadataTypedDict,
        NotificationStepDto,
        NotificationStepDtoTypedDict,
    )
    from .notificationtrigger import (
        NotificationTrigger,
        NotificationTriggerType,
        NotificationTriggerTypedDict,
    )
    from .notificationtriggerdto import (
        NotificationTriggerDto,
        NotificationTriggerDtoType,
        NotificationTriggerDtoTypedDict,
    )
    from .notificationtriggervariable import (
        NotificationTriggerVariable,
        NotificationTriggerVariableTypedDict,
    )
    from .ordinalenum import OrdinalEnum
    from .ordinalvalueenum import OrdinalValueEnum
    from .patchpreferencechannelsdto import (
        PatchPreferenceChannelsDto,
        PatchPreferenceChannelsDtoTypedDict,
    )
    from .patchsubscriberpreferencesdto import (
        PatchSubscriberPreferencesDto,
        PatchSubscriberPreferencesDtoTypedDict,
    )
    from .patchsubscriberrequestdto import (
        PatchSubscriberRequestDto,
        PatchSubscriberRequestDtoTypedDict,
    )
    from .preferenceoverridesourceenum import PreferenceOverrideSourceEnum
    from .providersidenum import ProvidersIDEnum
    from .removesubscriberresponsedto import (
        RemoveSubscriberResponseDto,
        RemoveSubscriberResponseDtoTypedDict,
    )
    from .replycallback import ReplyCallback, ReplyCallbackTypedDict
    from .security import Security, SecurityTypedDict
    from .stepfilterdto import StepFilterDto, StepFilterDtoTypedDict, StepFilterDtoValue
    from .stepsoverrides import StepsOverrides, StepsOverridesTypedDict
    from .steptypeenum import StepTypeEnum
    from .subscriberchanneldto import (
        ProviderID,
        SubscriberChannelDto,
        SubscriberChannelDtoTypedDict,
    )
    from .subscriberdto import SubscriberDto, SubscriberDtoTypedDict
    from .subscriberfeedresponsedto import (
        SubscriberFeedResponseDto,
        SubscriberFeedResponseDtoTypedDict,
    )
    from .subscriberglobalpreferencedto import (
        SubscriberGlobalPreferenceDto,
        SubscriberGlobalPreferenceDtoTypedDict,
    )
    from .subscriberpayloaddto import (
        Data,
        DataTypedDict,
        SubscriberPayloadDto,
        SubscriberPayloadDtoTypedDict,
    )
    from .subscriberpreferencechannels import (
        SubscriberPreferenceChannels,
        SubscriberPreferenceChannelsTypedDict,
    )
    from .subscriberpreferenceoverridedto import (
        SubscriberPreferenceOverrideDto,
        SubscriberPreferenceOverrideDtoTypedDict,
    )
    from .subscriberpreferencesworkflowinfodto import (
        SubscriberPreferencesWorkflowInfoDto,
        SubscriberPreferencesWorkflowInfoDtoTypedDict,
    )
    from .subscriberresponsedto import (
        SubscriberResponseDto,
        SubscriberResponseDtoTypedDict,
    )
    from .subscriberscontroller_createsubscriberop import (
        SubscribersControllerCreateSubscriberRequest,
        SubscribersControllerCreateSubscriberRequestTypedDict,
        SubscribersControllerCreateSubscriberResponse,
        SubscribersControllerCreateSubscriberResponseTypedDict,
    )
    from .subscriberscontroller_getsubscriberop import (
        SubscribersControllerGetSubscriberRequest,
        SubscribersControllerGetSubscriberRequestTypedDict,
        SubscribersControllerGetSubscriberResponse,
        SubscribersControllerGetSubscriberResponseTypedDict,
    )
    from .subscriberscontroller_getsubscriberpreferencesop import (
        SubscribersControllerGetSubscriberPreferencesRequest,
        SubscribersControllerGetSubscriberPreferencesRequestTypedDict,
        SubscribersControllerGetSubscriberPreferencesResponse,
        SubscribersControllerGetSubscriberPreferencesResponseTypedDict,
    )
    from .subscriberscontroller_listsubscribertopicsop import (
        QueryParamOrderDirection,
        SubscribersControllerListSubscriberTopicsRequest,
        SubscribersControllerListSubscriberTopicsRequestTypedDict,
        SubscribersControllerListSubscriberTopicsResponse,
        SubscribersControllerListSubscriberTopicsResponseTypedDict,
    )
    from .subscriberscontroller_patchsubscriberop import (
        SubscribersControllerPatchSubscriberRequest,
        SubscribersControllerPatchSubscriberRequestTypedDict,
        SubscribersControllerPatchSubscriberResponse,
        SubscribersControllerPatchSubscriberResponseTypedDict,
    )
    from .subscriberscontroller_removesubscriberop import (
        SubscribersControllerRemoveSubscriberRequest,
        SubscribersControllerRemoveSubscriberRequestTypedDict,
        SubscribersControllerRemoveSubscriberResponse,
        SubscribersControllerRemoveSubscriberResponseTypedDict,
    )
    from .subscriberscontroller_searchsubscribersop import (
        OrderDirection,
        SubscribersControllerSearchSubscribersRequest,
        SubscribersControllerSearchSubscribersRequestTypedDict,
        SubscribersControllerSearchSubscribersResponse,
        SubscribersControllerSearchSubscribersResponseTypedDict,
    )
    from .subscriberscontroller_updatesubscriberpreferencesop import (
        SubscribersControllerUpdateSubscriberPreferencesRequest,
        SubscribersControllerUpdateSubscriberPreferencesRequestTypedDict,
        SubscribersControllerUpdateSubscriberPreferencesResponse,
        SubscribersControllerUpdateSubscriberPreferencesResponseTypedDict,
    )
    from .subscribersv1controller_bulkcreatesubscribersop import (
        SubscribersV1ControllerBulkCreateSubscribersRequest,
        SubscribersV1ControllerBulkCreateSubscribersRequestTypedDict,
        SubscribersV1ControllerBulkCreateSubscribersResponse,
        SubscribersV1ControllerBulkCreateSubscribersResponseTypedDict,
    )
    from .subscribersv1controller_deletesubscribercredentialsop import (
        SubscribersV1ControllerDeleteSubscriberCredentialsRequest,
        SubscribersV1ControllerDeleteSubscriberCredentialsRequestTypedDict,
        SubscribersV1ControllerDeleteSubscriberCredentialsResponse,
        SubscribersV1ControllerDeleteSubscriberCredentialsResponseTypedDict,
    )
    from .subscribersv1controller_getnotificationsfeedop import (
        SubscribersV1ControllerGetNotificationsFeedRequest,
        SubscribersV1ControllerGetNotificationsFeedRequestTypedDict,
        SubscribersV1ControllerGetNotificationsFeedResponse,
        SubscribersV1ControllerGetNotificationsFeedResponseTypedDict,
    )
    from .subscribersv1controller_getunseencountop import (
        SubscribersV1ControllerGetUnseenCountRequest,
        SubscribersV1ControllerGetUnseenCountRequestTypedDict,
        SubscribersV1ControllerGetUnseenCountResponse,
        SubscribersV1ControllerGetUnseenCountResponseTypedDict,
    )
    from .subscribersv1controller_markactionasseenop import (
        SubscribersV1ControllerMarkActionAsSeenRequest,
        SubscribersV1ControllerMarkActionAsSeenRequestTypedDict,
        SubscribersV1ControllerMarkActionAsSeenResponse,
        SubscribersV1ControllerMarkActionAsSeenResponseTypedDict,
    )
    from .subscribersv1controller_markallunreadasreadop import (
        SubscribersV1ControllerMarkAllUnreadAsReadRequest,
        SubscribersV1ControllerMarkAllUnreadAsReadRequestTypedDict,
        SubscribersV1ControllerMarkAllUnreadAsReadResponse,
        SubscribersV1ControllerMarkAllUnreadAsReadResponseTypedDict,
    )
    from .subscribersv1controller_markmessagesasop import (
        SubscribersV1ControllerMarkMessagesAsRequest,
        SubscribersV1ControllerMarkMessagesAsRequestTypedDict,
        SubscribersV1ControllerMarkMessagesAsResponse,
        SubscribersV1ControllerMarkMessagesAsResponseTypedDict,
    )
    from .subscribersv1controller_modifysubscriberchannelop import (
        SubscribersV1ControllerModifySubscriberChannelRequest,
        SubscribersV1ControllerModifySubscriberChannelRequestTypedDict,
        SubscribersV1ControllerModifySubscriberChannelResponse,
        SubscribersV1ControllerModifySubscriberChannelResponseTypedDict,
    )
    from .subscribersv1controller_updatesubscriberchannelop import (
        SubscribersV1ControllerUpdateSubscriberChannelRequest,
        SubscribersV1ControllerUpdateSubscriberChannelRequestTypedDict,
        SubscribersV1ControllerUpdateSubscriberChannelResponse,
        SubscribersV1ControllerUpdateSubscriberChannelResponseTypedDict,
    )
    from .subscribersv1controller_updatesubscriberonlineflagop import (
        SubscribersV1ControllerUpdateSubscriberOnlineFlagRequest,
        SubscribersV1ControllerUpdateSubscriberOnlineFlagRequestTypedDict,
        SubscribersV1ControllerUpdateSubscriberOnlineFlagResponse,
        SubscribersV1ControllerUpdateSubscriberOnlineFlagResponseTypedDict,
    )
    from .subscriberworkflowpreferencedto import (
        SubscriberWorkflowPreferenceDto,
        SubscriberWorkflowPreferenceDtoTypedDict,
    )
    from .subscriptiondto import (
        Subscriber,
        SubscriberTypedDict,
        SubscriptionDto,
        SubscriptionDtoTypedDict,
    )
    from .subscriptionerrordto import (
        SubscriptionErrorDto,
        SubscriptionErrorDtoTypedDict,
    )
    from .subscriptionsdeleteerrordto import (
        SubscriptionsDeleteErrorDto,
        SubscriptionsDeleteErrorDtoTypedDict,
    )
    from .tenantpayloaddto import (
        TenantPayloadDto,
        TenantPayloadDtoData,
        TenantPayloadDtoDataTypedDict,
        TenantPayloadDtoTypedDict,
    )
    from .textalignenum import TextAlignEnum
    from .timedconfig import (
        MonthlyType,
        Ordinal,
        OrdinalValue,
        TimedConfig,
        TimedConfigTypedDict,
        WeekDays,
    )
    from .topicdto import TopicDto, TopicDtoTypedDict
    from .topicpayloaddto import TopicPayloadDto, TopicPayloadDtoTypedDict
    from .topicresponsedto import TopicResponseDto, TopicResponseDtoTypedDict
    from .topicscontroller_createtopicsubscriptionsop import (
        TopicsControllerCreateTopicSubscriptionsRequest,
        TopicsControllerCreateTopicSubscriptionsRequestTypedDict,
        TopicsControllerCreateTopicSubscriptionsResponse,
        TopicsControllerCreateTopicSubscriptionsResponseTypedDict,
    )
    from .topicscontroller_deletetopicop import (
        TopicsControllerDeleteTopicRequest,
        TopicsControllerDeleteTopicRequestTypedDict,
        TopicsControllerDeleteTopicResponse,
        TopicsControllerDeleteTopicResponseTypedDict,
    )
    from .topicscontroller_deletetopicsubscriptionsop import (
        TopicsControllerDeleteTopicSubscriptionsRequest,
        TopicsControllerDeleteTopicSubscriptionsRequestTypedDict,
        TopicsControllerDeleteTopicSubscriptionsResponse,
        TopicsControllerDeleteTopicSubscriptionsResponseTypedDict,
    )
    from .topicscontroller_gettopicop import (
        TopicsControllerGetTopicRequest,
        TopicsControllerGetTopicRequestTypedDict,
        TopicsControllerGetTopicResponse,
        TopicsControllerGetTopicResponseTypedDict,
    )
    from .topicscontroller_listtopicsop import (
        TopicsControllerListTopicsQueryParamOrderDirection,
        TopicsControllerListTopicsRequest,
        TopicsControllerListTopicsRequestTypedDict,
        TopicsControllerListTopicsResponse,
        TopicsControllerListTopicsResponseTypedDict,
    )
    from .topicscontroller_listtopicsubscriptionsop import (
        TopicsControllerListTopicSubscriptionsQueryParamOrderDirection,
        TopicsControllerListTopicSubscriptionsRequest,
        TopicsControllerListTopicSubscriptionsRequestTypedDict,
        TopicsControllerListTopicSubscriptionsResponse,
        TopicsControllerListTopicSubscriptionsResponseTypedDict,
    )
    from .topicscontroller_updatetopicop import (
        TopicsControllerUpdateTopicRequest,
        TopicsControllerUpdateTopicRequestTypedDict,
        TopicsControllerUpdateTopicResponse,
        TopicsControllerUpdateTopicResponseTypedDict,
    )
    from .topicscontroller_upserttopicop import (
        TopicsControllerUpsertTopicRequest,
        TopicsControllerUpsertTopicRequestTypedDict,
        TopicsControllerUpsertTopicResponse,
        TopicsControllerUpsertTopicResponseTypedDict,
    )
    from .topicsubscriberdto import TopicSubscriberDto, TopicSubscriberDtoTypedDict
    from .topicsubscriptionresponsedto import (
        TopicSubscriptionResponseDto,
        TopicSubscriptionResponseDtoTypedDict,
    )
    from .topicsv1controller_gettopicsubscriberop import (
        TopicsV1ControllerGetTopicSubscriberRequest,
        TopicsV1ControllerGetTopicSubscriberRequestTypedDict,
        TopicsV1ControllerGetTopicSubscriberResponse,
        TopicsV1ControllerGetTopicSubscriberResponseTypedDict,
    )
    from .triggereventrequestdto import (
        Actor,
        ActorTypedDict,
        One,
        OneTypedDict,
        Overrides,
        OverridesTypedDict,
        Tenant,
        TenantTypedDict,
        To,
        ToTypedDict,
        TriggerEventRequestDto,
        TriggerEventRequestDtoTypedDict,
    )
    from .triggereventresponsedto import (
        Status,
        TriggerEventResponseDto,
        TriggerEventResponseDtoTypedDict,
    )
    from .triggereventtoallrequestdto import (
        TriggerEventToAllRequestDto,
        TriggerEventToAllRequestDtoActor,
        TriggerEventToAllRequestDtoActorTypedDict,
        TriggerEventToAllRequestDtoOverrides,
        TriggerEventToAllRequestDtoOverridesTypedDict,
        TriggerEventToAllRequestDtoTenant,
        TriggerEventToAllRequestDtoTenantTypedDict,
        TriggerEventToAllRequestDtoTypedDict,
    )
    from .triggerrecipientstypeenum import TriggerRecipientsTypeEnum
    from .unseencountresponse import UnseenCountResponse, UnseenCountResponseTypedDict
    from .updatedsubscriberdto import (
        UpdatedSubscriberDto,
        UpdatedSubscriberDtoTypedDict,
    )
    from .updateintegrationrequestdto import (
        UpdateIntegrationRequestDto,
        UpdateIntegrationRequestDtoTypedDict,
    )
    from .updatesubscriberchannelrequestdto import (
        UpdateSubscriberChannelRequestDto,
        UpdateSubscriberChannelRequestDtoTypedDict,
    )
    from .updatesubscriberonlineflagrequestdto import (
        UpdateSubscriberOnlineFlagRequestDto,
        UpdateSubscriberOnlineFlagRequestDtoTypedDict,
    )
    from .updatetopicrequestdto import (
        UpdateTopicRequestDto,
        UpdateTopicRequestDtoTypedDict,
    )
    from .validationerrordto import (
        MessageValidationErrorDto4,
        MessageValidationErrorDto4TypedDict,
        MessageValidationErrorDto5,
        ValidationErrorDto,
        ValidationErrorDtoData,
        ValidationErrorDtoMessage,
    )
    from .workfloworiginenum import WorkflowOriginEnum
    from .workflowresponse import (
        WorkflowIntegrationStatus,
        WorkflowIntegrationStatusTypedDict,
        WorkflowResponse,
        WorkflowResponseData,
        WorkflowResponseDataTypedDict,
        WorkflowResponseTypedDict,
    )

__all__ = [
    "APIError",
    "ActivitiesResponseDto",
    "ActivitiesResponseDtoTypedDict",
    "ActivityNotificationExecutionDetailResponseDto",
    "ActivityNotificationExecutionDetailResponseDtoTypedDict",
    "ActivityNotificationJobResponseDto",
    "ActivityNotificationJobResponseDtoPayload",
    "ActivityNotificationJobResponseDtoPayloadTypedDict",
    "ActivityNotificationJobResponseDtoType",
    "ActivityNotificationJobResponseDtoTypedDict",
    "ActivityNotificationResponseDto",
    "ActivityNotificationResponseDtoPayload",
    "ActivityNotificationResponseDtoPayloadTypedDict",
    "ActivityNotificationResponseDtoTo",
    "ActivityNotificationResponseDtoToTypedDict",
    "ActivityNotificationResponseDtoTypedDict",
    "ActivityNotificationStepResponseDto",
    "ActivityNotificationStepResponseDtoMetadata",
    "ActivityNotificationStepResponseDtoMetadataTypedDict",
    "ActivityNotificationStepResponseDtoReplyCallback",
    "ActivityNotificationStepResponseDtoReplyCallbackTypedDict",
    "ActivityNotificationStepResponseDtoTypedDict",
    "ActivityNotificationSubscriberResponseDto",
    "ActivityNotificationSubscriberResponseDtoTypedDict",
    "ActivityNotificationTemplateResponseDto",
    "ActivityNotificationTemplateResponseDtoTypedDict",
    "ActivityTopicDto",
    "ActivityTopicDtoTypedDict",
    "Actor",
    "ActorFeedItemDto",
    "ActorFeedItemDtoTypedDict",
    "ActorTypeEnum",
    "ActorTypedDict",
    "BackoffUnit",
    "BuilderFieldTypeEnum",
    "BulkCreateSubscriberResponseDto",
    "BulkCreateSubscriberResponseDtoTypedDict",
    "BulkSubscriberCreateDto",
    "BulkSubscriberCreateDtoTypedDict",
    "BulkTriggerEventDto",
    "BulkTriggerEventDtoTypedDict",
    "ButtonTypeEnum",
    "Channel",
    "ChannelCTATypeEnum",
    "ChannelCredentials",
    "ChannelCredentialsDto",
    "ChannelCredentialsDtoTypedDict",
    "ChannelCredentialsTypedDict",
    "ChannelSettingsDto",
    "ChannelSettingsDtoTypedDict",
    "ChannelTypeEnum",
    "ChatOrPushProviderEnum",
    "ConstraintValidation",
    "ConstraintValidationTypedDict",
    "Content",
    "ContentTypedDict",
    "ControlVariables",
    "ControlVariablesTypedDict",
    "Controls",
    "ControlsTypedDict",
    "CreateIntegrationRequestDto",
    "CreateIntegrationRequestDtoChannel",
    "CreateIntegrationRequestDtoTypedDict",
    "CreateSubscriberRequestDto",
    "CreateSubscriberRequestDtoTypedDict",
    "CreateTopicSubscriptionsRequestDto",
    "CreateTopicSubscriptionsRequestDtoTypedDict",
    "CreateTopicSubscriptionsResponseDto",
    "CreateTopicSubscriptionsResponseDtoTypedDict",
    "CreateUpdateTopicRequestDto",
    "CreateUpdateTopicRequestDtoTypedDict",
    "CreatedSubscriberDto",
    "CreatedSubscriberDtoTypedDict",
    "CredentialsDto",
    "CredentialsDtoTypedDict",
    "Data",
    "DataTypedDict",
    "DelayRegularMetadata",
    "DelayRegularMetadataType",
    "DelayRegularMetadataTypedDict",
    "DelayRegularMetadataUnit",
    "DelayScheduledMetadata",
    "DelayScheduledMetadataType",
    "DelayScheduledMetadataTypedDict",
    "DeleteMessageResponseDto",
    "DeleteMessageResponseDtoStatus",
    "DeleteMessageResponseDtoTypedDict",
    "DeleteTopicResponseDto",
    "DeleteTopicResponseDtoTypedDict",
    "DeleteTopicSubscriptionsRequestDto",
    "DeleteTopicSubscriptionsRequestDtoTypedDict",
    "DeleteTopicSubscriptionsResponseDto",
    "DeleteTopicSubscriptionsResponseDtoTypedDict",
    "DigestMetadataDto",
    "DigestMetadataDtoTypedDict",
    "DigestMetadataDtoUnit",
    "DigestRegularMetadata",
    "DigestRegularMetadataTypedDict",
    "DigestTimedConfigDto",
    "DigestTimedConfigDtoTypedDict",
    "DigestTimedConfigDtoWeekDays",
    "DigestTimedMetadata",
    "DigestTimedMetadataType",
    "DigestTimedMetadataTypedDict",
    "DigestTimedMetadataUnit",
    "DigestTypeEnum",
    "DigestUnitEnum",
    "EmailBlock",
    "EmailBlockStyles",
    "EmailBlockStylesTypedDict",
    "EmailBlockTypeEnum",
    "EmailBlockTypedDict",
    "ErrorDto",
    "ErrorDtoData",
    "EventsControllerBroadcastEventToAllRequest",
    "EventsControllerBroadcastEventToAllRequestTypedDict",
    "EventsControllerBroadcastEventToAllResponse",
    "EventsControllerBroadcastEventToAllResponseTypedDict",
    "EventsControllerCancelRequest",
    "EventsControllerCancelRequestTypedDict",
    "EventsControllerCancelResponse",
    "EventsControllerCancelResponseTypedDict",
    "EventsControllerTriggerBulkRequest",
    "EventsControllerTriggerBulkRequestTypedDict",
    "EventsControllerTriggerBulkResponse",
    "EventsControllerTriggerBulkResponseTypedDict",
    "EventsControllerTriggerRequest",
    "EventsControllerTriggerRequestTypedDict",
    "EventsControllerTriggerResponse",
    "EventsControllerTriggerResponseTypedDict",
    "ExecutionDetailsSourceEnum",
    "ExecutionDetailsStatusEnum",
    "FailedOperationDto",
    "FailedOperationDtoTypedDict",
    "FeedIdentifier",
    "FeedIdentifierTypedDict",
    "FeedResponseDto",
    "FeedResponseDtoTypedDict",
    "FieldFilterPartDto",
    "FieldFilterPartDtoTypedDict",
    "Five",
    "FiveTypedDict",
    "Four",
    "FourTypedDict",
    "GetSubscriberPreferencesDto",
    "GetSubscriberPreferencesDtoTypedDict",
    "IntegrationResponseDto",
    "IntegrationResponseDtoTypedDict",
    "IntegrationsControllerCreateIntegrationRequest",
    "IntegrationsControllerCreateIntegrationRequestTypedDict",
    "IntegrationsControllerCreateIntegrationResponse",
    "IntegrationsControllerCreateIntegrationResponseTypedDict",
    "IntegrationsControllerGetActiveIntegrationsRequest",
    "IntegrationsControllerGetActiveIntegrationsRequestTypedDict",
    "IntegrationsControllerGetActiveIntegrationsResponse",
    "IntegrationsControllerGetActiveIntegrationsResponseTypedDict",
    "IntegrationsControllerListIntegrationsRequest",
    "IntegrationsControllerListIntegrationsRequestTypedDict",
    "IntegrationsControllerListIntegrationsResponse",
    "IntegrationsControllerListIntegrationsResponseTypedDict",
    "IntegrationsControllerRemoveIntegrationRequest",
    "IntegrationsControllerRemoveIntegrationRequestTypedDict",
    "IntegrationsControllerRemoveIntegrationResponse",
    "IntegrationsControllerRemoveIntegrationResponseTypedDict",
    "IntegrationsControllerSetIntegrationAsPrimaryRequest",
    "IntegrationsControllerSetIntegrationAsPrimaryRequestTypedDict",
    "IntegrationsControllerSetIntegrationAsPrimaryResponse",
    "IntegrationsControllerSetIntegrationAsPrimaryResponseTypedDict",
    "IntegrationsControllerUpdateIntegrationByIDRequest",
    "IntegrationsControllerUpdateIntegrationByIDRequestTypedDict",
    "IntegrationsControllerUpdateIntegrationByIDResponse",
    "IntegrationsControllerUpdateIntegrationByIDResponseTypedDict",
    "Issues",
    "IssuesTypedDict",
    "ListSubscribersResponseDto",
    "ListSubscribersResponseDtoTypedDict",
    "ListTopicSubscriptionsResponseDto",
    "ListTopicSubscriptionsResponseDtoTypedDict",
    "ListTopicsResponseDto",
    "ListTopicsResponseDtoTypedDict",
    "MarkAllMessageAsRequestDto",
    "MarkAllMessageAsRequestDtoTypedDict",
    "MarkAs",
    "MarkMessageActionAsSeenDto",
    "MarkMessageActionAsSeenDtoPayload",
    "MarkMessageActionAsSeenDtoPayloadTypedDict",
    "MarkMessageActionAsSeenDtoStatus",
    "MarkMessageActionAsSeenDtoTypedDict",
    "Message",
    "Message4",
    "Message4TypedDict",
    "Message5",
    "MessageAction",
    "MessageActionResult",
    "MessageActionResultTypedDict",
    "MessageActionStatusEnum",
    "MessageActionTypedDict",
    "MessageButton",
    "MessageButtonTypedDict",
    "MessageCTA",
    "MessageCTAData",
    "MessageCTADataTypedDict",
    "MessageCTATypedDict",
    "MessageID",
    "MessageIDTypedDict",
    "MessageMarkAsRequestDto",
    "MessageMarkAsRequestDtoMarkAs",
    "MessageMarkAsRequestDtoTypedDict",
    "MessageResponseDto",
    "MessageResponseDtoOverrides",
    "MessageResponseDtoOverridesTypedDict",
    "MessageResponseDtoPayload",
    "MessageResponseDtoPayloadTypedDict",
    "MessageResponseDtoTypedDict",
    "MessageStatusEnum",
    "MessageTemplate",
    "MessageTemplateDto",
    "MessageTemplateDtoTypedDict",
    "MessageTemplateTypedDict",
    "MessageValidationErrorDto4",
    "MessageValidationErrorDto4TypedDict",
    "MessageValidationErrorDto5",
    "MessagesControllerDeleteMessageRequest",
    "MessagesControllerDeleteMessageRequestTypedDict",
    "MessagesControllerDeleteMessageResponse",
    "MessagesControllerDeleteMessageResponseTypedDict",
    "MessagesControllerDeleteMessagesByTransactionIDRequest",
    "MessagesControllerDeleteMessagesByTransactionIDRequestTypedDict",
    "MessagesControllerDeleteMessagesByTransactionIDResponse",
    "MessagesControllerDeleteMessagesByTransactionIDResponseTypedDict",
    "MessagesControllerGetMessagesRequest",
    "MessagesControllerGetMessagesRequestTypedDict",
    "MessagesControllerGetMessagesResponse",
    "MessagesControllerGetMessagesResponseTypedDict",
    "MessagesResponseDto",
    "MessagesResponseDtoTypedDict",
    "MetaDto",
    "MetaDtoTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "MonthlyType",
    "MonthlyTypeEnum",
    "NotificationFeedItemDto",
    "NotificationFeedItemDtoStatus",
    "NotificationFeedItemDtoTypedDict",
    "NotificationGroup",
    "NotificationGroupTypedDict",
    "NotificationStepData",
    "NotificationStepDataMetadata",
    "NotificationStepDataMetadataTypedDict",
    "NotificationStepDataTypedDict",
    "NotificationStepDto",
    "NotificationStepDtoTypedDict",
    "NotificationTrigger",
    "NotificationTriggerDto",
    "NotificationTriggerDtoType",
    "NotificationTriggerDtoTypedDict",
    "NotificationTriggerType",
    "NotificationTriggerTypedDict",
    "NotificationTriggerVariable",
    "NotificationTriggerVariableTypedDict",
    "NotificationsControllerGetNotificationRequest",
    "NotificationsControllerGetNotificationRequestTypedDict",
    "NotificationsControllerGetNotificationResponse",
    "NotificationsControllerGetNotificationResponseTypedDict",
    "NotificationsControllerListNotificationsRequest",
    "NotificationsControllerListNotificationsRequestTypedDict",
    "NotificationsControllerListNotificationsResponse",
    "NotificationsControllerListNotificationsResponseTypedDict",
    "On",
    "One",
    "OneTypedDict",
    "Operator",
    "OrderDirection",
    "Ordinal",
    "OrdinalEnum",
    "OrdinalValue",
    "OrdinalValueEnum",
    "Overrides",
    "OverridesTypedDict",
    "PatchPreferenceChannelsDto",
    "PatchPreferenceChannelsDtoTypedDict",
    "PatchSubscriberPreferencesDto",
    "PatchSubscriberPreferencesDtoTypedDict",
    "PatchSubscriberRequestDto",
    "PatchSubscriberRequestDtoTypedDict",
    "Payload",
    "PayloadTypedDict",
    "PreferenceOverrideSourceEnum",
    "ProviderID",
    "ProvidersIDEnum",
    "QueryParamChannel",
    "QueryParamOrderDirection",
    "RemoveSubscriberResponseDto",
    "RemoveSubscriberResponseDtoTypedDict",
    "ReplyCallback",
    "ReplyCallbackTypedDict",
    "Security",
    "SecurityTypedDict",
    "Status",
    "StepFilterDto",
    "StepFilterDtoTypedDict",
    "StepFilterDtoValue",
    "StepTypeEnum",
    "StepsOverrides",
    "StepsOverridesTypedDict",
    "Subscriber",
    "SubscriberChannelDto",
    "SubscriberChannelDtoTypedDict",
    "SubscriberDto",
    "SubscriberDtoTypedDict",
    "SubscriberFeedResponseDto",
    "SubscriberFeedResponseDtoTypedDict",
    "SubscriberGlobalPreferenceDto",
    "SubscriberGlobalPreferenceDtoTypedDict",
    "SubscriberPayloadDto",
    "SubscriberPayloadDtoTypedDict",
    "SubscriberPreferenceChannels",
    "SubscriberPreferenceChannelsTypedDict",
    "SubscriberPreferenceOverrideDto",
    "SubscriberPreferenceOverrideDtoTypedDict",
    "SubscriberPreferencesWorkflowInfoDto",
    "SubscriberPreferencesWorkflowInfoDtoTypedDict",
    "SubscriberResponseDto",
    "SubscriberResponseDtoTypedDict",
    "SubscriberTypedDict",
    "SubscriberWorkflowPreferenceDto",
    "SubscriberWorkflowPreferenceDtoTypedDict",
    "SubscribersControllerCreateSubscriberRequest",
    "SubscribersControllerCreateSubscriberRequestTypedDict",
    "SubscribersControllerCreateSubscriberResponse",
    "SubscribersControllerCreateSubscriberResponseTypedDict",
    "SubscribersControllerGetSubscriberPreferencesRequest",
    "SubscribersControllerGetSubscriberPreferencesRequestTypedDict",
    "SubscribersControllerGetSubscriberPreferencesResponse",
    "SubscribersControllerGetSubscriberPreferencesResponseTypedDict",
    "SubscribersControllerGetSubscriberRequest",
    "SubscribersControllerGetSubscriberRequestTypedDict",
    "SubscribersControllerGetSubscriberResponse",
    "SubscribersControllerGetSubscriberResponseTypedDict",
    "SubscribersControllerListSubscriberTopicsRequest",
    "SubscribersControllerListSubscriberTopicsRequestTypedDict",
    "SubscribersControllerListSubscriberTopicsResponse",
    "SubscribersControllerListSubscriberTopicsResponseTypedDict",
    "SubscribersControllerPatchSubscriberRequest",
    "SubscribersControllerPatchSubscriberRequestTypedDict",
    "SubscribersControllerPatchSubscriberResponse",
    "SubscribersControllerPatchSubscriberResponseTypedDict",
    "SubscribersControllerRemoveSubscriberRequest",
    "SubscribersControllerRemoveSubscriberRequestTypedDict",
    "SubscribersControllerRemoveSubscriberResponse",
    "SubscribersControllerRemoveSubscriberResponseTypedDict",
    "SubscribersControllerSearchSubscribersRequest",
    "SubscribersControllerSearchSubscribersRequestTypedDict",
    "SubscribersControllerSearchSubscribersResponse",
    "SubscribersControllerSearchSubscribersResponseTypedDict",
    "SubscribersControllerUpdateSubscriberPreferencesRequest",
    "SubscribersControllerUpdateSubscriberPreferencesRequestTypedDict",
    "SubscribersControllerUpdateSubscriberPreferencesResponse",
    "SubscribersControllerUpdateSubscriberPreferencesResponseTypedDict",
    "SubscribersV1ControllerBulkCreateSubscribersRequest",
    "SubscribersV1ControllerBulkCreateSubscribersRequestTypedDict",
    "SubscribersV1ControllerBulkCreateSubscribersResponse",
    "SubscribersV1ControllerBulkCreateSubscribersResponseTypedDict",
    "SubscribersV1ControllerDeleteSubscriberCredentialsRequest",
    "SubscribersV1ControllerDeleteSubscriberCredentialsRequestTypedDict",
    "SubscribersV1ControllerDeleteSubscriberCredentialsResponse",
    "SubscribersV1ControllerDeleteSubscriberCredentialsResponseTypedDict",
    "SubscribersV1ControllerGetNotificationsFeedRequest",
    "SubscribersV1ControllerGetNotificationsFeedRequestTypedDict",
    "SubscribersV1ControllerGetNotificationsFeedResponse",
    "SubscribersV1ControllerGetNotificationsFeedResponseTypedDict",
    "SubscribersV1ControllerGetUnseenCountRequest",
    "SubscribersV1ControllerGetUnseenCountRequestTypedDict",
    "SubscribersV1ControllerGetUnseenCountResponse",
    "SubscribersV1ControllerGetUnseenCountResponseTypedDict",
    "SubscribersV1ControllerMarkActionAsSeenRequest",
    "SubscribersV1ControllerMarkActionAsSeenRequestTypedDict",
    "SubscribersV1ControllerMarkActionAsSeenResponse",
    "SubscribersV1ControllerMarkActionAsSeenResponseTypedDict",
    "SubscribersV1ControllerMarkAllUnreadAsReadRequest",
    "SubscribersV1ControllerMarkAllUnreadAsReadRequestTypedDict",
    "SubscribersV1ControllerMarkAllUnreadAsReadResponse",
    "SubscribersV1ControllerMarkAllUnreadAsReadResponseTypedDict",
    "SubscribersV1ControllerMarkMessagesAsRequest",
    "SubscribersV1ControllerMarkMessagesAsRequestTypedDict",
    "SubscribersV1ControllerMarkMessagesAsResponse",
    "SubscribersV1ControllerMarkMessagesAsResponseTypedDict",
    "SubscribersV1ControllerModifySubscriberChannelRequest",
    "SubscribersV1ControllerModifySubscriberChannelRequestTypedDict",
    "SubscribersV1ControllerModifySubscriberChannelResponse",
    "SubscribersV1ControllerModifySubscriberChannelResponseTypedDict",
    "SubscribersV1ControllerUpdateSubscriberChannelRequest",
    "SubscribersV1ControllerUpdateSubscriberChannelRequestTypedDict",
    "SubscribersV1ControllerUpdateSubscriberChannelResponse",
    "SubscribersV1ControllerUpdateSubscriberChannelResponseTypedDict",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagRequest",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagRequestTypedDict",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagResponse",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagResponseTypedDict",
    "SubscriptionDto",
    "SubscriptionDtoTypedDict",
    "SubscriptionErrorDto",
    "SubscriptionErrorDtoTypedDict",
    "SubscriptionsDeleteErrorDto",
    "SubscriptionsDeleteErrorDtoTypedDict",
    "TLSOptions",
    "TLSOptionsTypedDict",
    "Tenant",
    "TenantPayloadDto",
    "TenantPayloadDtoData",
    "TenantPayloadDtoDataTypedDict",
    "TenantPayloadDtoTypedDict",
    "TenantTypedDict",
    "TextAlignEnum",
    "TimedConfig",
    "TimedConfigTypedDict",
    "To",
    "ToTypedDict",
    "TopicDto",
    "TopicDtoTypedDict",
    "TopicPayloadDto",
    "TopicPayloadDtoTypedDict",
    "TopicResponseDto",
    "TopicResponseDtoTypedDict",
    "TopicSubscriberDto",
    "TopicSubscriberDtoTypedDict",
    "TopicSubscriptionResponseDto",
    "TopicSubscriptionResponseDtoTypedDict",
    "TopicsControllerCreateTopicSubscriptionsRequest",
    "TopicsControllerCreateTopicSubscriptionsRequestTypedDict",
    "TopicsControllerCreateTopicSubscriptionsResponse",
    "TopicsControllerCreateTopicSubscriptionsResponseTypedDict",
    "TopicsControllerDeleteTopicRequest",
    "TopicsControllerDeleteTopicRequestTypedDict",
    "TopicsControllerDeleteTopicResponse",
    "TopicsControllerDeleteTopicResponseTypedDict",
    "TopicsControllerDeleteTopicSubscriptionsRequest",
    "TopicsControllerDeleteTopicSubscriptionsRequestTypedDict",
    "TopicsControllerDeleteTopicSubscriptionsResponse",
    "TopicsControllerDeleteTopicSubscriptionsResponseTypedDict",
    "TopicsControllerGetTopicRequest",
    "TopicsControllerGetTopicRequestTypedDict",
    "TopicsControllerGetTopicResponse",
    "TopicsControllerGetTopicResponseTypedDict",
    "TopicsControllerListTopicSubscriptionsQueryParamOrderDirection",
    "TopicsControllerListTopicSubscriptionsRequest",
    "TopicsControllerListTopicSubscriptionsRequestTypedDict",
    "TopicsControllerListTopicSubscriptionsResponse",
    "TopicsControllerListTopicSubscriptionsResponseTypedDict",
    "TopicsControllerListTopicsQueryParamOrderDirection",
    "TopicsControllerListTopicsRequest",
    "TopicsControllerListTopicsRequestTypedDict",
    "TopicsControllerListTopicsResponse",
    "TopicsControllerListTopicsResponseTypedDict",
    "TopicsControllerUpdateTopicRequest",
    "TopicsControllerUpdateTopicRequestTypedDict",
    "TopicsControllerUpdateTopicResponse",
    "TopicsControllerUpdateTopicResponseTypedDict",
    "TopicsControllerUpsertTopicRequest",
    "TopicsControllerUpsertTopicRequestTypedDict",
    "TopicsControllerUpsertTopicResponse",
    "TopicsControllerUpsertTopicResponseTypedDict",
    "TopicsV1ControllerGetTopicSubscriberRequest",
    "TopicsV1ControllerGetTopicSubscriberRequestTypedDict",
    "TopicsV1ControllerGetTopicSubscriberResponse",
    "TopicsV1ControllerGetTopicSubscriberResponseTypedDict",
    "TriggerEventRequestDto",
    "TriggerEventRequestDtoTypedDict",
    "TriggerEventResponseDto",
    "TriggerEventResponseDtoTypedDict",
    "TriggerEventToAllRequestDto",
    "TriggerEventToAllRequestDtoActor",
    "TriggerEventToAllRequestDtoActorTypedDict",
    "TriggerEventToAllRequestDtoOverrides",
    "TriggerEventToAllRequestDtoOverridesTypedDict",
    "TriggerEventToAllRequestDtoTenant",
    "TriggerEventToAllRequestDtoTenantTypedDict",
    "TriggerEventToAllRequestDtoTypedDict",
    "TriggerRecipientsTypeEnum",
    "Type",
    "Unit",
    "UnseenCountResponse",
    "UnseenCountResponseTypedDict",
    "UpdateIntegrationRequestDto",
    "UpdateIntegrationRequestDtoTypedDict",
    "UpdateSubscriberChannelRequestDto",
    "UpdateSubscriberChannelRequestDtoTypedDict",
    "UpdateSubscriberOnlineFlagRequestDto",
    "UpdateSubscriberOnlineFlagRequestDtoTypedDict",
    "UpdateTopicRequestDto",
    "UpdateTopicRequestDtoTypedDict",
    "UpdatedSubscriberDto",
    "UpdatedSubscriberDtoTypedDict",
    "ValidationErrorDto",
    "ValidationErrorDtoData",
    "ValidationErrorDtoMessage",
    "Value",
    "ValueTypedDict",
    "WeekDays",
    "WorkflowIntegrationStatus",
    "WorkflowIntegrationStatusTypedDict",
    "WorkflowOriginEnum",
    "WorkflowResponse",
    "WorkflowResponseData",
    "WorkflowResponseDataTypedDict",
    "WorkflowResponseTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "ActivitiesResponseDto": ".activitiesresponsedto",
    "ActivitiesResponseDtoTypedDict": ".activitiesresponsedto",
    "ActivityNotificationExecutionDetailResponseDto": ".activitynotificationexecutiondetailresponsedto",
    "ActivityNotificationExecutionDetailResponseDtoTypedDict": ".activitynotificationexecutiondetailresponsedto",
    "ActivityNotificationJobResponseDto": ".activitynotificationjobresponsedto",
    "ActivityNotificationJobResponseDtoPayload": ".activitynotificationjobresponsedto",
    "ActivityNotificationJobResponseDtoPayloadTypedDict": ".activitynotificationjobresponsedto",
    "ActivityNotificationJobResponseDtoType": ".activitynotificationjobresponsedto",
    "ActivityNotificationJobResponseDtoTypedDict": ".activitynotificationjobresponsedto",
    "ActivityNotificationResponseDto": ".activitynotificationresponsedto",
    "ActivityNotificationResponseDtoPayload": ".activitynotificationresponsedto",
    "ActivityNotificationResponseDtoPayloadTypedDict": ".activitynotificationresponsedto",
    "ActivityNotificationResponseDtoTo": ".activitynotificationresponsedto",
    "ActivityNotificationResponseDtoToTypedDict": ".activitynotificationresponsedto",
    "ActivityNotificationResponseDtoTypedDict": ".activitynotificationresponsedto",
    "Controls": ".activitynotificationresponsedto",
    "ControlsTypedDict": ".activitynotificationresponsedto",
    "ActivityNotificationStepResponseDto": ".activitynotificationstepresponsedto",
    "ActivityNotificationStepResponseDtoMetadata": ".activitynotificationstepresponsedto",
    "ActivityNotificationStepResponseDtoMetadataTypedDict": ".activitynotificationstepresponsedto",
    "ActivityNotificationStepResponseDtoReplyCallback": ".activitynotificationstepresponsedto",
    "ActivityNotificationStepResponseDtoReplyCallbackTypedDict": ".activitynotificationstepresponsedto",
    "ActivityNotificationStepResponseDtoTypedDict": ".activitynotificationstepresponsedto",
    "ControlVariables": ".activitynotificationstepresponsedto",
    "ControlVariablesTypedDict": ".activitynotificationstepresponsedto",
    "Issues": ".activitynotificationstepresponsedto",
    "IssuesTypedDict": ".activitynotificationstepresponsedto",
    "ActivityNotificationSubscriberResponseDto": ".activitynotificationsubscriberresponsedto",
    "ActivityNotificationSubscriberResponseDtoTypedDict": ".activitynotificationsubscriberresponsedto",
    "ActivityNotificationTemplateResponseDto": ".activitynotificationtemplateresponsedto",
    "ActivityNotificationTemplateResponseDtoTypedDict": ".activitynotificationtemplateresponsedto",
    "ActivityTopicDto": ".activitytopicdto",
    "ActivityTopicDtoTypedDict": ".activitytopicdto",
    "ActorFeedItemDto": ".actorfeeditemdto",
    "ActorFeedItemDtoTypedDict": ".actorfeeditemdto",
    "ActorTypeEnum": ".actortypeenum",
    "APIError": ".apierror",
    "BuilderFieldTypeEnum": ".builderfieldtypeenum",
    "BulkCreateSubscriberResponseDto": ".bulkcreatesubscriberresponsedto",
    "BulkCreateSubscriberResponseDtoTypedDict": ".bulkcreatesubscriberresponsedto",
    "BulkSubscriberCreateDto": ".bulksubscribercreatedto",
    "BulkSubscriberCreateDtoTypedDict": ".bulksubscribercreatedto",
    "BulkTriggerEventDto": ".bulktriggereventdto",
    "BulkTriggerEventDtoTypedDict": ".bulktriggereventdto",
    "ButtonTypeEnum": ".buttontypeenum",
    "ChannelCredentials": ".channelcredentials",
    "ChannelCredentialsTypedDict": ".channelcredentials",
    "ChannelCredentialsDto": ".channelcredentialsdto",
    "ChannelCredentialsDtoTypedDict": ".channelcredentialsdto",
    "ChannelCTATypeEnum": ".channelctatypeenum",
    "ChannelSettingsDto": ".channelsettingsdto",
    "ChannelSettingsDtoTypedDict": ".channelsettingsdto",
    "ChannelTypeEnum": ".channeltypeenum",
    "ChatOrPushProviderEnum": ".chatorpushproviderenum",
    "ConstraintValidation": ".constraintvalidation",
    "ConstraintValidationTypedDict": ".constraintvalidation",
    "Five": ".constraintvalidation",
    "FiveTypedDict": ".constraintvalidation",
    "Four": ".constraintvalidation",
    "FourTypedDict": ".constraintvalidation",
    "Value": ".constraintvalidation",
    "ValueTypedDict": ".constraintvalidation",
    "CreatedSubscriberDto": ".createdsubscriberdto",
    "CreatedSubscriberDtoTypedDict": ".createdsubscriberdto",
    "CreateIntegrationRequestDto": ".createintegrationrequestdto",
    "CreateIntegrationRequestDtoChannel": ".createintegrationrequestdto",
    "CreateIntegrationRequestDtoTypedDict": ".createintegrationrequestdto",
    "CreateSubscriberRequestDto": ".createsubscriberrequestdto",
    "CreateSubscriberRequestDtoTypedDict": ".createsubscriberrequestdto",
    "CreateTopicSubscriptionsRequestDto": ".createtopicsubscriptionsrequestdto",
    "CreateTopicSubscriptionsRequestDtoTypedDict": ".createtopicsubscriptionsrequestdto",
    "CreateTopicSubscriptionsResponseDto": ".createtopicsubscriptionsresponsedto",
    "CreateTopicSubscriptionsResponseDtoTypedDict": ".createtopicsubscriptionsresponsedto",
    "CreateUpdateTopicRequestDto": ".createupdatetopicrequestdto",
    "CreateUpdateTopicRequestDtoTypedDict": ".createupdatetopicrequestdto",
    "CredentialsDto": ".credentialsdto",
    "CredentialsDtoTypedDict": ".credentialsdto",
    "TLSOptions": ".credentialsdto",
    "TLSOptionsTypedDict": ".credentialsdto",
    "DelayRegularMetadata": ".delayregularmetadata",
    "DelayRegularMetadataType": ".delayregularmetadata",
    "DelayRegularMetadataTypedDict": ".delayregularmetadata",
    "DelayRegularMetadataUnit": ".delayregularmetadata",
    "DelayScheduledMetadata": ".delayscheduledmetadata",
    "DelayScheduledMetadataType": ".delayscheduledmetadata",
    "DelayScheduledMetadataTypedDict": ".delayscheduledmetadata",
    "DeleteMessageResponseDto": ".deletemessageresponsedto",
    "DeleteMessageResponseDtoStatus": ".deletemessageresponsedto",
    "DeleteMessageResponseDtoTypedDict": ".deletemessageresponsedto",
    "DeleteTopicResponseDto": ".deletetopicresponsedto",
    "DeleteTopicResponseDtoTypedDict": ".deletetopicresponsedto",
    "DeleteTopicSubscriptionsRequestDto": ".deletetopicsubscriptionsrequestdto",
    "DeleteTopicSubscriptionsRequestDtoTypedDict": ".deletetopicsubscriptionsrequestdto",
    "DeleteTopicSubscriptionsResponseDto": ".deletetopicsubscriptionsresponsedto",
    "DeleteTopicSubscriptionsResponseDtoTypedDict": ".deletetopicsubscriptionsresponsedto",
    "DigestMetadataDto": ".digestmetadatadto",
    "DigestMetadataDtoTypedDict": ".digestmetadatadto",
    "DigestMetadataDtoUnit": ".digestmetadatadto",
    "BackoffUnit": ".digestregularmetadata",
    "DigestRegularMetadata": ".digestregularmetadata",
    "DigestRegularMetadataTypedDict": ".digestregularmetadata",
    "Type": ".digestregularmetadata",
    "Unit": ".digestregularmetadata",
    "DigestTimedConfigDto": ".digesttimedconfigdto",
    "DigestTimedConfigDtoTypedDict": ".digesttimedconfigdto",
    "DigestTimedConfigDtoWeekDays": ".digesttimedconfigdto",
    "DigestTimedMetadata": ".digesttimedmetadata",
    "DigestTimedMetadataType": ".digesttimedmetadata",
    "DigestTimedMetadataTypedDict": ".digesttimedmetadata",
    "DigestTimedMetadataUnit": ".digesttimedmetadata",
    "DigestTypeEnum": ".digesttypeenum",
    "DigestUnitEnum": ".digestunitenum",
    "EmailBlock": ".emailblock",
    "EmailBlockTypedDict": ".emailblock",
    "EmailBlockStyles": ".emailblockstyles",
    "EmailBlockStylesTypedDict": ".emailblockstyles",
    "EmailBlockTypeEnum": ".emailblocktypeenum",
    "ErrorDto": ".errordto",
    "ErrorDtoData": ".errordto",
    "Message": ".errordto",
    "Message4": ".errordto",
    "Message4TypedDict": ".errordto",
    "Message5": ".errordto",
    "EventsControllerBroadcastEventToAllRequest": ".eventscontroller_broadcasteventtoallop",
    "EventsControllerBroadcastEventToAllRequestTypedDict": ".eventscontroller_broadcasteventtoallop",
    "EventsControllerBroadcastEventToAllResponse": ".eventscontroller_broadcasteventtoallop",
    "EventsControllerBroadcastEventToAllResponseTypedDict": ".eventscontroller_broadcasteventtoallop",
    "EventsControllerCancelRequest": ".eventscontroller_cancelop",
    "EventsControllerCancelRequestTypedDict": ".eventscontroller_cancelop",
    "EventsControllerCancelResponse": ".eventscontroller_cancelop",
    "EventsControllerCancelResponseTypedDict": ".eventscontroller_cancelop",
    "EventsControllerTriggerBulkRequest": ".eventscontroller_triggerbulkop",
    "EventsControllerTriggerBulkRequestTypedDict": ".eventscontroller_triggerbulkop",
    "EventsControllerTriggerBulkResponse": ".eventscontroller_triggerbulkop",
    "EventsControllerTriggerBulkResponseTypedDict": ".eventscontroller_triggerbulkop",
    "EventsControllerTriggerRequest": ".eventscontroller_triggerop",
    "EventsControllerTriggerRequestTypedDict": ".eventscontroller_triggerop",
    "EventsControllerTriggerResponse": ".eventscontroller_triggerop",
    "EventsControllerTriggerResponseTypedDict": ".eventscontroller_triggerop",
    "ExecutionDetailsSourceEnum": ".executiondetailssourceenum",
    "ExecutionDetailsStatusEnum": ".executiondetailsstatusenum",
    "FailedOperationDto": ".failedoperationdto",
    "FailedOperationDtoTypedDict": ".failedoperationdto",
    "FeedResponseDto": ".feedresponsedto",
    "FeedResponseDtoTypedDict": ".feedresponsedto",
    "FieldFilterPartDto": ".fieldfilterpartdto",
    "FieldFilterPartDtoTypedDict": ".fieldfilterpartdto",
    "On": ".fieldfilterpartdto",
    "Operator": ".fieldfilterpartdto",
    "GetSubscriberPreferencesDto": ".getsubscriberpreferencesdto",
    "GetSubscriberPreferencesDtoTypedDict": ".getsubscriberpreferencesdto",
    "Channel": ".integrationresponsedto",
    "IntegrationResponseDto": ".integrationresponsedto",
    "IntegrationResponseDtoTypedDict": ".integrationresponsedto",
    "IntegrationsControllerCreateIntegrationRequest": ".integrationscontroller_createintegrationop",
    "IntegrationsControllerCreateIntegrationRequestTypedDict": ".integrationscontroller_createintegrationop",
    "IntegrationsControllerCreateIntegrationResponse": ".integrationscontroller_createintegrationop",
    "IntegrationsControllerCreateIntegrationResponseTypedDict": ".integrationscontroller_createintegrationop",
    "IntegrationsControllerGetActiveIntegrationsRequest": ".integrationscontroller_getactiveintegrationsop",
    "IntegrationsControllerGetActiveIntegrationsRequestTypedDict": ".integrationscontroller_getactiveintegrationsop",
    "IntegrationsControllerGetActiveIntegrationsResponse": ".integrationscontroller_getactiveintegrationsop",
    "IntegrationsControllerGetActiveIntegrationsResponseTypedDict": ".integrationscontroller_getactiveintegrationsop",
    "IntegrationsControllerListIntegrationsRequest": ".integrationscontroller_listintegrationsop",
    "IntegrationsControllerListIntegrationsRequestTypedDict": ".integrationscontroller_listintegrationsop",
    "IntegrationsControllerListIntegrationsResponse": ".integrationscontroller_listintegrationsop",
    "IntegrationsControllerListIntegrationsResponseTypedDict": ".integrationscontroller_listintegrationsop",
    "IntegrationsControllerRemoveIntegrationRequest": ".integrationscontroller_removeintegrationop",
    "IntegrationsControllerRemoveIntegrationRequestTypedDict": ".integrationscontroller_removeintegrationop",
    "IntegrationsControllerRemoveIntegrationResponse": ".integrationscontroller_removeintegrationop",
    "IntegrationsControllerRemoveIntegrationResponseTypedDict": ".integrationscontroller_removeintegrationop",
    "IntegrationsControllerSetIntegrationAsPrimaryRequest": ".integrationscontroller_setintegrationasprimaryop",
    "IntegrationsControllerSetIntegrationAsPrimaryRequestTypedDict": ".integrationscontroller_setintegrationasprimaryop",
    "IntegrationsControllerSetIntegrationAsPrimaryResponse": ".integrationscontroller_setintegrationasprimaryop",
    "IntegrationsControllerSetIntegrationAsPrimaryResponseTypedDict": ".integrationscontroller_setintegrationasprimaryop",
    "IntegrationsControllerUpdateIntegrationByIDRequest": ".integrationscontroller_updateintegrationbyidop",
    "IntegrationsControllerUpdateIntegrationByIDRequestTypedDict": ".integrationscontroller_updateintegrationbyidop",
    "IntegrationsControllerUpdateIntegrationByIDResponse": ".integrationscontroller_updateintegrationbyidop",
    "IntegrationsControllerUpdateIntegrationByIDResponseTypedDict": ".integrationscontroller_updateintegrationbyidop",
    "ListSubscribersResponseDto": ".listsubscribersresponsedto",
    "ListSubscribersResponseDtoTypedDict": ".listsubscribersresponsedto",
    "ListTopicsResponseDto": ".listtopicsresponsedto",
    "ListTopicsResponseDtoTypedDict": ".listtopicsresponsedto",
    "ListTopicSubscriptionsResponseDto": ".listtopicsubscriptionsresponsedto",
    "ListTopicSubscriptionsResponseDtoTypedDict": ".listtopicsubscriptionsresponsedto",
    "FeedIdentifier": ".markallmessageasrequestdto",
    "FeedIdentifierTypedDict": ".markallmessageasrequestdto",
    "MarkAllMessageAsRequestDto": ".markallmessageasrequestdto",
    "MarkAllMessageAsRequestDtoTypedDict": ".markallmessageasrequestdto",
    "MarkAs": ".markallmessageasrequestdto",
    "MarkMessageActionAsSeenDto": ".markmessageactionasseendto",
    "MarkMessageActionAsSeenDtoPayload": ".markmessageactionasseendto",
    "MarkMessageActionAsSeenDtoPayloadTypedDict": ".markmessageactionasseendto",
    "MarkMessageActionAsSeenDtoStatus": ".markmessageactionasseendto",
    "MarkMessageActionAsSeenDtoTypedDict": ".markmessageactionasseendto",
    "MessageAction": ".messageaction",
    "MessageActionTypedDict": ".messageaction",
    "MessageActionResult": ".messageactionresult",
    "MessageActionResultTypedDict": ".messageactionresult",
    "Payload": ".messageactionresult",
    "PayloadTypedDict": ".messageactionresult",
    "MessageActionStatusEnum": ".messageactionstatusenum",
    "MessageButton": ".messagebutton",
    "MessageButtonTypedDict": ".messagebutton",
    "MessageCTA": ".messagecta",
    "MessageCTATypedDict": ".messagecta",
    "MessageCTAData": ".messagectadata",
    "MessageCTADataTypedDict": ".messagectadata",
    "MessageID": ".messagemarkasrequestdto",
    "MessageIDTypedDict": ".messagemarkasrequestdto",
    "MessageMarkAsRequestDto": ".messagemarkasrequestdto",
    "MessageMarkAsRequestDtoMarkAs": ".messagemarkasrequestdto",
    "MessageMarkAsRequestDtoTypedDict": ".messagemarkasrequestdto",
    "Content": ".messageresponsedto",
    "ContentTypedDict": ".messageresponsedto",
    "MessageResponseDto": ".messageresponsedto",
    "MessageResponseDtoOverrides": ".messageresponsedto",
    "MessageResponseDtoOverridesTypedDict": ".messageresponsedto",
    "MessageResponseDtoPayload": ".messageresponsedto",
    "MessageResponseDtoPayloadTypedDict": ".messageresponsedto",
    "MessageResponseDtoTypedDict": ".messageresponsedto",
    "MessagesControllerDeleteMessageRequest": ".messagescontroller_deletemessageop",
    "MessagesControllerDeleteMessageRequestTypedDict": ".messagescontroller_deletemessageop",
    "MessagesControllerDeleteMessageResponse": ".messagescontroller_deletemessageop",
    "MessagesControllerDeleteMessageResponseTypedDict": ".messagescontroller_deletemessageop",
    "MessagesControllerDeleteMessagesByTransactionIDRequest": ".messagescontroller_deletemessagesbytransactionidop",
    "MessagesControllerDeleteMessagesByTransactionIDRequestTypedDict": ".messagescontroller_deletemessagesbytransactionidop",
    "MessagesControllerDeleteMessagesByTransactionIDResponse": ".messagescontroller_deletemessagesbytransactionidop",
    "MessagesControllerDeleteMessagesByTransactionIDResponseTypedDict": ".messagescontroller_deletemessagesbytransactionidop",
    "QueryParamChannel": ".messagescontroller_deletemessagesbytransactionidop",
    "MessagesControllerGetMessagesRequest": ".messagescontroller_getmessagesop",
    "MessagesControllerGetMessagesRequestTypedDict": ".messagescontroller_getmessagesop",
    "MessagesControllerGetMessagesResponse": ".messagescontroller_getmessagesop",
    "MessagesControllerGetMessagesResponseTypedDict": ".messagescontroller_getmessagesop",
    "MessagesResponseDto": ".messagesresponsedto",
    "MessagesResponseDtoTypedDict": ".messagesresponsedto",
    "MessageStatusEnum": ".messagestatusenum",
    "MessageTemplate": ".messagetemplate",
    "MessageTemplateTypedDict": ".messagetemplate",
    "MessageTemplateDto": ".messagetemplatedto",
    "MessageTemplateDtoTypedDict": ".messagetemplatedto",
    "MetaDto": ".metadto",
    "MetaDtoTypedDict": ".metadto",
    "MonthlyTypeEnum": ".monthlytypeenum",
    "NotificationFeedItemDto": ".notificationfeeditemdto",
    "NotificationFeedItemDtoStatus": ".notificationfeeditemdto",
    "NotificationFeedItemDtoTypedDict": ".notificationfeeditemdto",
    "NotificationGroup": ".notificationgroup",
    "NotificationGroupTypedDict": ".notificationgroup",
    "NotificationsControllerGetNotificationRequest": ".notificationscontroller_getnotificationop",
    "NotificationsControllerGetNotificationRequestTypedDict": ".notificationscontroller_getnotificationop",
    "NotificationsControllerGetNotificationResponse": ".notificationscontroller_getnotificationop",
    "NotificationsControllerGetNotificationResponseTypedDict": ".notificationscontroller_getnotificationop",
    "NotificationsControllerListNotificationsRequest": ".notificationscontroller_listnotificationsop",
    "NotificationsControllerListNotificationsRequestTypedDict": ".notificationscontroller_listnotificationsop",
    "NotificationsControllerListNotificationsResponse": ".notificationscontroller_listnotificationsop",
    "NotificationsControllerListNotificationsResponseTypedDict": ".notificationscontroller_listnotificationsop",
    "NotificationStepData": ".notificationstepdata",
    "NotificationStepDataMetadata": ".notificationstepdata",
    "NotificationStepDataMetadataTypedDict": ".notificationstepdata",
    "NotificationStepDataTypedDict": ".notificationstepdata",
    "Metadata": ".notificationstepdto",
    "MetadataTypedDict": ".notificationstepdto",
    "NotificationStepDto": ".notificationstepdto",
    "NotificationStepDtoTypedDict": ".notificationstepdto",
    "NotificationTrigger": ".notificationtrigger",
    "NotificationTriggerType": ".notificationtrigger",
    "NotificationTriggerTypedDict": ".notificationtrigger",
    "NotificationTriggerDto": ".notificationtriggerdto",
    "NotificationTriggerDtoType": ".notificationtriggerdto",
    "NotificationTriggerDtoTypedDict": ".notificationtriggerdto",
    "NotificationTriggerVariable": ".notificationtriggervariable",
    "NotificationTriggerVariableTypedDict": ".notificationtriggervariable",
    "OrdinalEnum": ".ordinalenum",
    "OrdinalValueEnum": ".ordinalvalueenum",
    "PatchPreferenceChannelsDto": ".patchpreferencechannelsdto",
    "PatchPreferenceChannelsDtoTypedDict": ".patchpreferencechannelsdto",
    "PatchSubscriberPreferencesDto": ".patchsubscriberpreferencesdto",
    "PatchSubscriberPreferencesDtoTypedDict": ".patchsubscriberpreferencesdto",
    "PatchSubscriberRequestDto": ".patchsubscriberrequestdto",
    "PatchSubscriberRequestDtoTypedDict": ".patchsubscriberrequestdto",
    "PreferenceOverrideSourceEnum": ".preferenceoverridesourceenum",
    "ProvidersIDEnum": ".providersidenum",
    "RemoveSubscriberResponseDto": ".removesubscriberresponsedto",
    "RemoveSubscriberResponseDtoTypedDict": ".removesubscriberresponsedto",
    "ReplyCallback": ".replycallback",
    "ReplyCallbackTypedDict": ".replycallback",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "StepFilterDto": ".stepfilterdto",
    "StepFilterDtoTypedDict": ".stepfilterdto",
    "StepFilterDtoValue": ".stepfilterdto",
    "StepsOverrides": ".stepsoverrides",
    "StepsOverridesTypedDict": ".stepsoverrides",
    "StepTypeEnum": ".steptypeenum",
    "ProviderID": ".subscriberchanneldto",
    "SubscriberChannelDto": ".subscriberchanneldto",
    "SubscriberChannelDtoTypedDict": ".subscriberchanneldto",
    "SubscriberDto": ".subscriberdto",
    "SubscriberDtoTypedDict": ".subscriberdto",
    "SubscriberFeedResponseDto": ".subscriberfeedresponsedto",
    "SubscriberFeedResponseDtoTypedDict": ".subscriberfeedresponsedto",
    "SubscriberGlobalPreferenceDto": ".subscriberglobalpreferencedto",
    "SubscriberGlobalPreferenceDtoTypedDict": ".subscriberglobalpreferencedto",
    "Data": ".subscriberpayloaddto",
    "DataTypedDict": ".subscriberpayloaddto",
    "SubscriberPayloadDto": ".subscriberpayloaddto",
    "SubscriberPayloadDtoTypedDict": ".subscriberpayloaddto",
    "SubscriberPreferenceChannels": ".subscriberpreferencechannels",
    "SubscriberPreferenceChannelsTypedDict": ".subscriberpreferencechannels",
    "SubscriberPreferenceOverrideDto": ".subscriberpreferenceoverridedto",
    "SubscriberPreferenceOverrideDtoTypedDict": ".subscriberpreferenceoverridedto",
    "SubscriberPreferencesWorkflowInfoDto": ".subscriberpreferencesworkflowinfodto",
    "SubscriberPreferencesWorkflowInfoDtoTypedDict": ".subscriberpreferencesworkflowinfodto",
    "SubscriberResponseDto": ".subscriberresponsedto",
    "SubscriberResponseDtoTypedDict": ".subscriberresponsedto",
    "SubscribersControllerCreateSubscriberRequest": ".subscriberscontroller_createsubscriberop",
    "SubscribersControllerCreateSubscriberRequestTypedDict": ".subscriberscontroller_createsubscriberop",
    "SubscribersControllerCreateSubscriberResponse": ".subscriberscontroller_createsubscriberop",
    "SubscribersControllerCreateSubscriberResponseTypedDict": ".subscriberscontroller_createsubscriberop",
    "SubscribersControllerGetSubscriberRequest": ".subscriberscontroller_getsubscriberop",
    "SubscribersControllerGetSubscriberRequestTypedDict": ".subscriberscontroller_getsubscriberop",
    "SubscribersControllerGetSubscriberResponse": ".subscriberscontroller_getsubscriberop",
    "SubscribersControllerGetSubscriberResponseTypedDict": ".subscriberscontroller_getsubscriberop",
    "SubscribersControllerGetSubscriberPreferencesRequest": ".subscriberscontroller_getsubscriberpreferencesop",
    "SubscribersControllerGetSubscriberPreferencesRequestTypedDict": ".subscriberscontroller_getsubscriberpreferencesop",
    "SubscribersControllerGetSubscriberPreferencesResponse": ".subscriberscontroller_getsubscriberpreferencesop",
    "SubscribersControllerGetSubscriberPreferencesResponseTypedDict": ".subscriberscontroller_getsubscriberpreferencesop",
    "QueryParamOrderDirection": ".subscriberscontroller_listsubscribertopicsop",
    "SubscribersControllerListSubscriberTopicsRequest": ".subscriberscontroller_listsubscribertopicsop",
    "SubscribersControllerListSubscriberTopicsRequestTypedDict": ".subscriberscontroller_listsubscribertopicsop",
    "SubscribersControllerListSubscriberTopicsResponse": ".subscriberscontroller_listsubscribertopicsop",
    "SubscribersControllerListSubscriberTopicsResponseTypedDict": ".subscriberscontroller_listsubscribertopicsop",
    "SubscribersControllerPatchSubscriberRequest": ".subscriberscontroller_patchsubscriberop",
    "SubscribersControllerPatchSubscriberRequestTypedDict": ".subscriberscontroller_patchsubscriberop",
    "SubscribersControllerPatchSubscriberResponse": ".subscriberscontroller_patchsubscriberop",
    "SubscribersControllerPatchSubscriberResponseTypedDict": ".subscriberscontroller_patchsubscriberop",
    "SubscribersControllerRemoveSubscriberRequest": ".subscriberscontroller_removesubscriberop",
    "SubscribersControllerRemoveSubscriberRequestTypedDict": ".subscriberscontroller_removesubscriberop",
    "SubscribersControllerRemoveSubscriberResponse": ".subscriberscontroller_removesubscriberop",
    "SubscribersControllerRemoveSubscriberResponseTypedDict": ".subscriberscontroller_removesubscriberop",
    "OrderDirection": ".subscriberscontroller_searchsubscribersop",
    "SubscribersControllerSearchSubscribersRequest": ".subscriberscontroller_searchsubscribersop",
    "SubscribersControllerSearchSubscribersRequestTypedDict": ".subscriberscontroller_searchsubscribersop",
    "SubscribersControllerSearchSubscribersResponse": ".subscriberscontroller_searchsubscribersop",
    "SubscribersControllerSearchSubscribersResponseTypedDict": ".subscriberscontroller_searchsubscribersop",
    "SubscribersControllerUpdateSubscriberPreferencesRequest": ".subscriberscontroller_updatesubscriberpreferencesop",
    "SubscribersControllerUpdateSubscriberPreferencesRequestTypedDict": ".subscriberscontroller_updatesubscriberpreferencesop",
    "SubscribersControllerUpdateSubscriberPreferencesResponse": ".subscriberscontroller_updatesubscriberpreferencesop",
    "SubscribersControllerUpdateSubscriberPreferencesResponseTypedDict": ".subscriberscontroller_updatesubscriberpreferencesop",
    "SubscribersV1ControllerBulkCreateSubscribersRequest": ".subscribersv1controller_bulkcreatesubscribersop",
    "SubscribersV1ControllerBulkCreateSubscribersRequestTypedDict": ".subscribersv1controller_bulkcreatesubscribersop",
    "SubscribersV1ControllerBulkCreateSubscribersResponse": ".subscribersv1controller_bulkcreatesubscribersop",
    "SubscribersV1ControllerBulkCreateSubscribersResponseTypedDict": ".subscribersv1controller_bulkcreatesubscribersop",
    "SubscribersV1ControllerDeleteSubscriberCredentialsRequest": ".subscribersv1controller_deletesubscribercredentialsop",
    "SubscribersV1ControllerDeleteSubscriberCredentialsRequestTypedDict": ".subscribersv1controller_deletesubscribercredentialsop",
    "SubscribersV1ControllerDeleteSubscriberCredentialsResponse": ".subscribersv1controller_deletesubscribercredentialsop",
    "SubscribersV1ControllerDeleteSubscriberCredentialsResponseTypedDict": ".subscribersv1controller_deletesubscribercredentialsop",
    "SubscribersV1ControllerGetNotificationsFeedRequest": ".subscribersv1controller_getnotificationsfeedop",
    "SubscribersV1ControllerGetNotificationsFeedRequestTypedDict": ".subscribersv1controller_getnotificationsfeedop",
    "SubscribersV1ControllerGetNotificationsFeedResponse": ".subscribersv1controller_getnotificationsfeedop",
    "SubscribersV1ControllerGetNotificationsFeedResponseTypedDict": ".subscribersv1controller_getnotificationsfeedop",
    "SubscribersV1ControllerGetUnseenCountRequest": ".subscribersv1controller_getunseencountop",
    "SubscribersV1ControllerGetUnseenCountRequestTypedDict": ".subscribersv1controller_getunseencountop",
    "SubscribersV1ControllerGetUnseenCountResponse": ".subscribersv1controller_getunseencountop",
    "SubscribersV1ControllerGetUnseenCountResponseTypedDict": ".subscribersv1controller_getunseencountop",
    "SubscribersV1ControllerMarkActionAsSeenRequest": ".subscribersv1controller_markactionasseenop",
    "SubscribersV1ControllerMarkActionAsSeenRequestTypedDict": ".subscribersv1controller_markactionasseenop",
    "SubscribersV1ControllerMarkActionAsSeenResponse": ".subscribersv1controller_markactionasseenop",
    "SubscribersV1ControllerMarkActionAsSeenResponseTypedDict": ".subscribersv1controller_markactionasseenop",
    "SubscribersV1ControllerMarkAllUnreadAsReadRequest": ".subscribersv1controller_markallunreadasreadop",
    "SubscribersV1ControllerMarkAllUnreadAsReadRequestTypedDict": ".subscribersv1controller_markallunreadasreadop",
    "SubscribersV1ControllerMarkAllUnreadAsReadResponse": ".subscribersv1controller_markallunreadasreadop",
    "SubscribersV1ControllerMarkAllUnreadAsReadResponseTypedDict": ".subscribersv1controller_markallunreadasreadop",
    "SubscribersV1ControllerMarkMessagesAsRequest": ".subscribersv1controller_markmessagesasop",
    "SubscribersV1ControllerMarkMessagesAsRequestTypedDict": ".subscribersv1controller_markmessagesasop",
    "SubscribersV1ControllerMarkMessagesAsResponse": ".subscribersv1controller_markmessagesasop",
    "SubscribersV1ControllerMarkMessagesAsResponseTypedDict": ".subscribersv1controller_markmessagesasop",
    "SubscribersV1ControllerModifySubscriberChannelRequest": ".subscribersv1controller_modifysubscriberchannelop",
    "SubscribersV1ControllerModifySubscriberChannelRequestTypedDict": ".subscribersv1controller_modifysubscriberchannelop",
    "SubscribersV1ControllerModifySubscriberChannelResponse": ".subscribersv1controller_modifysubscriberchannelop",
    "SubscribersV1ControllerModifySubscriberChannelResponseTypedDict": ".subscribersv1controller_modifysubscriberchannelop",
    "SubscribersV1ControllerUpdateSubscriberChannelRequest": ".subscribersv1controller_updatesubscriberchannelop",
    "SubscribersV1ControllerUpdateSubscriberChannelRequestTypedDict": ".subscribersv1controller_updatesubscriberchannelop",
    "SubscribersV1ControllerUpdateSubscriberChannelResponse": ".subscribersv1controller_updatesubscriberchannelop",
    "SubscribersV1ControllerUpdateSubscriberChannelResponseTypedDict": ".subscribersv1controller_updatesubscriberchannelop",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagRequest": ".subscribersv1controller_updatesubscriberonlineflagop",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagRequestTypedDict": ".subscribersv1controller_updatesubscriberonlineflagop",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagResponse": ".subscribersv1controller_updatesubscriberonlineflagop",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagResponseTypedDict": ".subscribersv1controller_updatesubscriberonlineflagop",
    "SubscriberWorkflowPreferenceDto": ".subscriberworkflowpreferencedto",
    "SubscriberWorkflowPreferenceDtoTypedDict": ".subscriberworkflowpreferencedto",
    "Subscriber": ".subscriptiondto",
    "SubscriberTypedDict": ".subscriptiondto",
    "SubscriptionDto": ".subscriptiondto",
    "SubscriptionDtoTypedDict": ".subscriptiondto",
    "SubscriptionErrorDto": ".subscriptionerrordto",
    "SubscriptionErrorDtoTypedDict": ".subscriptionerrordto",
    "SubscriptionsDeleteErrorDto": ".subscriptionsdeleteerrordto",
    "SubscriptionsDeleteErrorDtoTypedDict": ".subscriptionsdeleteerrordto",
    "TenantPayloadDto": ".tenantpayloaddto",
    "TenantPayloadDtoData": ".tenantpayloaddto",
    "TenantPayloadDtoDataTypedDict": ".tenantpayloaddto",
    "TenantPayloadDtoTypedDict": ".tenantpayloaddto",
    "TextAlignEnum": ".textalignenum",
    "MonthlyType": ".timedconfig",
    "Ordinal": ".timedconfig",
    "OrdinalValue": ".timedconfig",
    "TimedConfig": ".timedconfig",
    "TimedConfigTypedDict": ".timedconfig",
    "WeekDays": ".timedconfig",
    "TopicDto": ".topicdto",
    "TopicDtoTypedDict": ".topicdto",
    "TopicPayloadDto": ".topicpayloaddto",
    "TopicPayloadDtoTypedDict": ".topicpayloaddto",
    "TopicResponseDto": ".topicresponsedto",
    "TopicResponseDtoTypedDict": ".topicresponsedto",
    "TopicsControllerCreateTopicSubscriptionsRequest": ".topicscontroller_createtopicsubscriptionsop",
    "TopicsControllerCreateTopicSubscriptionsRequestTypedDict": ".topicscontroller_createtopicsubscriptionsop",
    "TopicsControllerCreateTopicSubscriptionsResponse": ".topicscontroller_createtopicsubscriptionsop",
    "TopicsControllerCreateTopicSubscriptionsResponseTypedDict": ".topicscontroller_createtopicsubscriptionsop",
    "TopicsControllerDeleteTopicRequest": ".topicscontroller_deletetopicop",
    "TopicsControllerDeleteTopicRequestTypedDict": ".topicscontroller_deletetopicop",
    "TopicsControllerDeleteTopicResponse": ".topicscontroller_deletetopicop",
    "TopicsControllerDeleteTopicResponseTypedDict": ".topicscontroller_deletetopicop",
    "TopicsControllerDeleteTopicSubscriptionsRequest": ".topicscontroller_deletetopicsubscriptionsop",
    "TopicsControllerDeleteTopicSubscriptionsRequestTypedDict": ".topicscontroller_deletetopicsubscriptionsop",
    "TopicsControllerDeleteTopicSubscriptionsResponse": ".topicscontroller_deletetopicsubscriptionsop",
    "TopicsControllerDeleteTopicSubscriptionsResponseTypedDict": ".topicscontroller_deletetopicsubscriptionsop",
    "TopicsControllerGetTopicRequest": ".topicscontroller_gettopicop",
    "TopicsControllerGetTopicRequestTypedDict": ".topicscontroller_gettopicop",
    "TopicsControllerGetTopicResponse": ".topicscontroller_gettopicop",
    "TopicsControllerGetTopicResponseTypedDict": ".topicscontroller_gettopicop",
    "TopicsControllerListTopicsQueryParamOrderDirection": ".topicscontroller_listtopicsop",
    "TopicsControllerListTopicsRequest": ".topicscontroller_listtopicsop",
    "TopicsControllerListTopicsRequestTypedDict": ".topicscontroller_listtopicsop",
    "TopicsControllerListTopicsResponse": ".topicscontroller_listtopicsop",
    "TopicsControllerListTopicsResponseTypedDict": ".topicscontroller_listtopicsop",
    "TopicsControllerListTopicSubscriptionsQueryParamOrderDirection": ".topicscontroller_listtopicsubscriptionsop",
    "TopicsControllerListTopicSubscriptionsRequest": ".topicscontroller_listtopicsubscriptionsop",
    "TopicsControllerListTopicSubscriptionsRequestTypedDict": ".topicscontroller_listtopicsubscriptionsop",
    "TopicsControllerListTopicSubscriptionsResponse": ".topicscontroller_listtopicsubscriptionsop",
    "TopicsControllerListTopicSubscriptionsResponseTypedDict": ".topicscontroller_listtopicsubscriptionsop",
    "TopicsControllerUpdateTopicRequest": ".topicscontroller_updatetopicop",
    "TopicsControllerUpdateTopicRequestTypedDict": ".topicscontroller_updatetopicop",
    "TopicsControllerUpdateTopicResponse": ".topicscontroller_updatetopicop",
    "TopicsControllerUpdateTopicResponseTypedDict": ".topicscontroller_updatetopicop",
    "TopicsControllerUpsertTopicRequest": ".topicscontroller_upserttopicop",
    "TopicsControllerUpsertTopicRequestTypedDict": ".topicscontroller_upserttopicop",
    "TopicsControllerUpsertTopicResponse": ".topicscontroller_upserttopicop",
    "TopicsControllerUpsertTopicResponseTypedDict": ".topicscontroller_upserttopicop",
    "TopicSubscriberDto": ".topicsubscriberdto",
    "TopicSubscriberDtoTypedDict": ".topicsubscriberdto",
    "TopicSubscriptionResponseDto": ".topicsubscriptionresponsedto",
    "TopicSubscriptionResponseDtoTypedDict": ".topicsubscriptionresponsedto",
    "TopicsV1ControllerGetTopicSubscriberRequest": ".topicsv1controller_gettopicsubscriberop",
    "TopicsV1ControllerGetTopicSubscriberRequestTypedDict": ".topicsv1controller_gettopicsubscriberop",
    "TopicsV1ControllerGetTopicSubscriberResponse": ".topicsv1controller_gettopicsubscriberop",
    "TopicsV1ControllerGetTopicSubscriberResponseTypedDict": ".topicsv1controller_gettopicsubscriberop",
    "Actor": ".triggereventrequestdto",
    "ActorTypedDict": ".triggereventrequestdto",
    "One": ".triggereventrequestdto",
    "OneTypedDict": ".triggereventrequestdto",
    "Overrides": ".triggereventrequestdto",
    "OverridesTypedDict": ".triggereventrequestdto",
    "Tenant": ".triggereventrequestdto",
    "TenantTypedDict": ".triggereventrequestdto",
    "To": ".triggereventrequestdto",
    "ToTypedDict": ".triggereventrequestdto",
    "TriggerEventRequestDto": ".triggereventrequestdto",
    "TriggerEventRequestDtoTypedDict": ".triggereventrequestdto",
    "Status": ".triggereventresponsedto",
    "TriggerEventResponseDto": ".triggereventresponsedto",
    "TriggerEventResponseDtoTypedDict": ".triggereventresponsedto",
    "TriggerEventToAllRequestDto": ".triggereventtoallrequestdto",
    "TriggerEventToAllRequestDtoActor": ".triggereventtoallrequestdto",
    "TriggerEventToAllRequestDtoActorTypedDict": ".triggereventtoallrequestdto",
    "TriggerEventToAllRequestDtoOverrides": ".triggereventtoallrequestdto",
    "TriggerEventToAllRequestDtoOverridesTypedDict": ".triggereventtoallrequestdto",
    "TriggerEventToAllRequestDtoTenant": ".triggereventtoallrequestdto",
    "TriggerEventToAllRequestDtoTenantTypedDict": ".triggereventtoallrequestdto",
    "TriggerEventToAllRequestDtoTypedDict": ".triggereventtoallrequestdto",
    "TriggerRecipientsTypeEnum": ".triggerrecipientstypeenum",
    "UnseenCountResponse": ".unseencountresponse",
    "UnseenCountResponseTypedDict": ".unseencountresponse",
    "UpdatedSubscriberDto": ".updatedsubscriberdto",
    "UpdatedSubscriberDtoTypedDict": ".updatedsubscriberdto",
    "UpdateIntegrationRequestDto": ".updateintegrationrequestdto",
    "UpdateIntegrationRequestDtoTypedDict": ".updateintegrationrequestdto",
    "UpdateSubscriberChannelRequestDto": ".updatesubscriberchannelrequestdto",
    "UpdateSubscriberChannelRequestDtoTypedDict": ".updatesubscriberchannelrequestdto",
    "UpdateSubscriberOnlineFlagRequestDto": ".updatesubscriberonlineflagrequestdto",
    "UpdateSubscriberOnlineFlagRequestDtoTypedDict": ".updatesubscriberonlineflagrequestdto",
    "UpdateTopicRequestDto": ".updatetopicrequestdto",
    "UpdateTopicRequestDtoTypedDict": ".updatetopicrequestdto",
    "MessageValidationErrorDto4": ".validationerrordto",
    "MessageValidationErrorDto4TypedDict": ".validationerrordto",
    "MessageValidationErrorDto5": ".validationerrordto",
    "ValidationErrorDto": ".validationerrordto",
    "ValidationErrorDtoData": ".validationerrordto",
    "ValidationErrorDtoMessage": ".validationerrordto",
    "WorkflowOriginEnum": ".workfloworiginenum",
    "WorkflowIntegrationStatus": ".workflowresponse",
    "WorkflowIntegrationStatusTypedDict": ".workflowresponse",
    "WorkflowResponse": ".workflowresponse",
    "WorkflowResponseData": ".workflowresponse",
    "WorkflowResponseDataTypedDict": ".workflowresponse",
    "WorkflowResponseTypedDict": ".workflowresponse",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriberchanneldto import SubscriberChannelDto, SubscriberChannelDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from typing import Dict, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


DataTypedDict = TypeAliasType("DataTypedDict", Union[str, List[str], bool, float])


Data = TypeAliasType("Data", Union[str, List[str], bool, float])


class SubscriberPayloadDtoTypedDict(TypedDict):
    subscriber_id: str
    r"""The internal identifier you used to create this subscriber, usually correlates to the id the user in your systems"""
    email: NotRequired[str]
    r"""The email address of the subscriber."""
    first_name: NotRequired[str]
    r"""The first name of the subscriber."""
    last_name: NotRequired[str]
    r"""The last name of the subscriber."""
    phone: NotRequired[str]
    r"""The phone number of the subscriber."""
    avatar: NotRequired[str]
    r"""An HTTP URL to the profile image of your subscriber."""
    locale: NotRequired[str]
    r"""The locale of the subscriber."""
    data: NotRequired[Dict[str, DataTypedDict]]
    r"""An optional payload object that can contain any properties."""
    channels: NotRequired[List[SubscriberChannelDtoTypedDict]]
    r"""An optional array of subscriber channels."""
    timezone: NotRequired[str]
    r"""The timezone of the subscriber."""


class SubscriberPayloadDto(BaseModel):
    subscriber_id: Annotated[str, pydantic.Field(alias="subscriberId")]
    r"""The internal identifier you used to create this subscriber, usually correlates to the id the user in your systems"""

    email: Optional[str] = None
    r"""The email address of the subscriber."""

    first_name: Annotated[Optional[str], pydantic.Field(alias="firstName")] = None
    r"""The first name of the subscriber."""

    last_name: Annotated[Optional[str], pydantic.Field(alias="lastName")] = None
    r"""The last name of the subscriber."""

    phone: Optional[str] = None
    r"""The phone number of the subscriber."""

    avatar: Optional[str] = None
    r"""An HTTP URL to the profile image of your subscriber."""

    locale: Optional[str] = None
    r"""The locale of the subscriber."""

    data: Optional[Dict[str, Data]] = None
    r"""An optional payload object that can contain any properties."""

    channels: Optional[List[SubscriberChannelDto]] = None
    r"""An optional array of subscriber channels."""

    timezone: Optional[str] = None
    r"""The timezone of the subscriber."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .triggerrecipientstypeenum import TriggerRecipientsTypeEnum
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class TopicPayloadDtoTypedDict(TypedDict):
    topic_key: str
    type: TriggerRecipientsTypeEnum


class TopicPayloadDto(BaseModel):
    topic_key: Annotated[str, pydantic.Field(alias="topicKey")]

    type: TriggerRecipientsTypeEnum



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .credentialsdto import CredentialsDto, CredentialsDtoTypedDict
from .stepfilterdto import StepFilterDto, StepFilterDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UpdateIntegrationRequestDtoTypedDict(TypedDict):
    name: NotRequired[str]
    identifier: NotRequired[str]
    environment_id: NotRequired[str]
    active: NotRequired[bool]
    r"""If the integration is active the validation on the credentials field will run"""
    credentials: NotRequired[CredentialsDtoTypedDict]
    remove_novu_branding: NotRequired[bool]
    r"""If true, the Novu branding will be removed from the Inbox component"""
    check: NotRequired[bool]
    conditions: NotRequired[List[StepFilterDtoTypedDict]]


class UpdateIntegrationRequestDto(BaseModel):
    name: Optional[str] = None

    identifier: Optional[str] = None

    environment_id: Annotated[Optional[str], pydantic.Field(alias="_environmentId")] = (
        None
    )

    active: Optional[bool] = None
    r"""If the integration is active the validation on the credentials field will run"""

    credentials: Optional[CredentialsDto] = None

    remove_novu_branding: Annotated[
        Optional[bool], pydantic.Field(alias="removeNovuBranding")
    ] = None
    r"""If true, the Novu branding will be removed from the Inbox component"""

    check: Optional[bool] = None

    conditions: Optional[List[StepFilterDto]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class CreateTopicSubscriptionsRequestDtoTypedDict(TypedDict):
    subscriber_ids: List[str]
    r"""List of subscriber identifiers to subscribe to the topic (max: 100)"""


class CreateTopicSubscriptionsRequestDto(BaseModel):
    subscriber_ids: Annotated[List[str], pydantic.Field(alias="subscriberIds")]
    r"""List of subscriber identifiers to subscribe to the topic (max: 100)"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py import utils
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET
import pydantic
from typing import Any, Dict, List, Optional, Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


Message5TypedDict = TypeAliasType(
    "Message5TypedDict", Union[str, float, bool, Dict[str, Any]]
)


Message5 = TypeAliasType("Message5", Union[str, float, bool, Dict[str, Any]])


class Message4TypedDict(TypedDict):
    pass


class Message4(BaseModel):
    pass


MessageTypedDict = TypeAliasType(
    "MessageTypedDict",
    Union[Message4TypedDict, str, float, bool, List[Nullable[Message5TypedDict]]],
)
r"""Value that failed validation"""


Message = TypeAliasType(
    "Message", Union[Message4, str, float, bool, List[Nullable[Message5]]]
)
r"""Value that failed validation"""


class ErrorDtoData(BaseModel):
    status_code: Annotated[float, pydantic.Field(alias="statusCode")]
    r"""HTTP status code of the error response."""

    timestamp: str
    r"""Timestamp of when the error occurred."""

    path: str
    r"""The path where the error occurred."""

    message: OptionalNullable[Message] = UNSET
    r"""Value that failed validation"""

    ctx: Optional[Dict[str, Any]] = None
    r"""Optional context object for additional error details."""

    error_id: Annotated[Optional[str], pydantic.Field(alias="errorId")] = None
    r"""Optional unique identifier for the error, useful for tracking using Sentry and
    New Relic, only available for 500.
    """


class ErrorDto(Exception):
    data: ErrorDtoData

    def __init__(self, data: ErrorDtoData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, ErrorDtoData)
